% File src/library/base/man/Foreign.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{Foreign}
\alias{Foreign}
\alias{.C}
\alias{.Fortran}
\title{Foreign Function Interface}
\description{
\R に読み込まれているコンパイル済みコードへの呼び出しを行う関数.
}
\usage{
       .C(.NAME, \dots, NAOK = FALSE, DUP = TRUE, PACKAGE, ENCODING)
 .Fortran(.NAME, \dots, NAOK = FALSE, DUP = TRUE, PACKAGE, ENCODING)
}
\arguments{
  \item{.NAME}{文字列．C 関数，Fortran サブルーティンの名前を与える．
またはそうした名前へを参照するクラス 
\code{"\link{NativeSymbolInfo}"}, \code{"\link{RegisteredNativeSymbol}"}
もしくは \code{"\link{NativeSymbol}"} のオブジェクト.}
  \item{\dots}{外部関数へ引き渡される引数．最大65.}
  \item{NAOK}{もし \code{TRUE} ならば引数中の \code{\link{NA}}，
\code{\link{NaN}} または \code{\link{Inf}} 値は
外部関数に引き渡される．もし \code{FALSE} ならば, 
\code{NA}，\code{NaN} またはr \code{Inf} 値はエラーとされる.}
  \item{PACKAGE}{もし与えられれば，文字列 \code{.NAME} の検索は
この引数で与えられる DLL に限られる(加えて慣例的な拡張子 
\file{.so}, \file{.dll}, \dots).

これはパッケージの安全性を与えることを意図しており，
この引数を他のパッケージがそれらの外部シンボルを書き換えず，
また検索の速度を向上させる(\sQuote{Note} を見よ).}

  \item{DUP, ENCODING}{過去への互換性のため．受け入れられるが無視される.}
}

\details{
これらの関数はコンパイルされた C と Fortran コードへの呼び出しをするのに使うことが出来る．
最近のインタフェイスは \code{\link{.Call}} と \code{\link{.External}} で，
より柔軟で優れた性能を持つ．

これらの関数は \link{primitive} で, \code{.NAME} は常に与えられた
最初の引数(名前を持つべきではない)にマッチする．
他の名前付き引数は \code{\dots} に続くので，省略できない．
明快さのために， \code{.NAME} にマッチもしくは部分的にマッチする
\code{\dots} に引き渡される引数中で名前を使うことを避けるべきである．
}

\value{
引き渡される \code{\dots} 引数リストと類似のリスト
(引数に与えられたすべての名前を含む)だが，
 C や Fortran コードによりなされる変更を反映する． 
}

\section{引数の型}{
C または Fortran 引数への \R 引数のマッピングは次のようになる

  \tabular{lll}{
    \R \tab     C \tab     Fortran\cr
    integer \tab int * \tab integer\cr
    numeric \tab double * \tab double precision\cr
    -- or -- \tab float * \tab real\cr
    complex \tab Rcomplex * \tab double complex\cr
    logical \tab int * \tab integer \cr
    character \tab char ** \tab [以下を見よ]\cr
    raw \tab unsigned char * \tab 許されない\cr
    list \tab SEXP *\tab 許されない\cr
    その他 \tab SEXP\tab 許されない\cr
  }

\emph{注意：}
\code{integer} と \code{logical} に対応する C の型は S と同様に
 \code{int} であり，\code{long} ではない．この違いは
 \code{int} が32ビットで \code{long} が64ビットである(64-ビット Windows ではそうではない).
 ほとんどの64ビットプラットフォームで問題になる．

\emph{注意：} \code{logical} に対応する Fortran の方は \code{integer}
であり \code{logical} ではない：この違いはある種の 
Fortran コンパイラで問題になる．
  
\code{Csingle} が \code{TRUE} と設定(
\code{\link{as.single}} または \code{\link{single}} を使う)されていない限り，
\R の数値ベクトルは C に \code{double *} として(Fortran では
\code{double precision}として)引き渡される．
この機構は既存の C と Fortran コードへのインタフェイスを容易にする
ことだけを意図している．

C の型 \code{Rcomplex} は \file{Complex.h} 中に 
 \code{typedef struct {double r; double i;}} として定義されている．
これは使用するコンパイラによって C99 の \code{double complex} 型に
同値であったりなかったりする．

論理値は \code{0} (\code{FALSE}), \code{1}
 (\code{TRUE}) または \code{INT_MIN = -2147483648}
 (\code{NA}，しかし \code{NAOK = TRUE} の時だけ) として渡される．
そしてコンパイル済みコードはこれらの三つの値のいずれかを返すべきである：
しかしながら \code{INT_MIN} 以外の非ゼロ値は \code{TRUE} にマップされる．

欠損 (\code{NA}) 文字列は \code{.C} に文字列 "NA" として
渡される．C の \code{char} 型はすべての可能なビットパターンを表現できるので，
欠損文字列と文字列 \code{"NA"} を区別する方法は無いと思われる．
もしこの区別が重要なら \code{\link{.Call}} を使おう．

\code{.Fortran} は文字列ベクトルの最初(だけ)の文字列を 
C の文字配列として Fortran に渡す：もし真の長さが別個に
引き渡されるのなら，これは \code{character*255} として
使えるかもしれない．文字列の最大255の文字だけが返される．
(そしてこれが動作したとしても，どのように上手く動作するかは
 C と Fortran コンパイラそしてプラットフォームに依存する.)

リスト，関数，そして他の \R オブジェクトは(歴史的な理由から)
 \code{.C} に引き渡されるが，\code{\link{.Call}} インタフェイスは
もっと好ましい．原子的なベクトルを除くすべての入力は読み込み専用と
みなすべきである．そしてベクトル(リストを含む)を除き，関数や
環境は廃止されている．
}

\section{Fortran のシンボル名}{
\R をコンパイルするのに使えることが知られているすべての Fortran コンパイラは
シンボル名を小文字でマップする．従って \code{.Fortran} も同様である.

アンダースコアを含むシンボル名は Fortran77 では不正である
(Fortran 9x では許される)．多くの Fortran 77 コンパイラはそれらを
許すかもしれないが，アンダースコアを含まない名前に異なった仕方で
翻訳するかもしれない．そうした名前はしばしば \code{.Fortran}
(それらがどのように翻訳されるかは \R が構築される際に検出され，
その情報は \code{.Fortran} により使われる)で使えるかもしれないが，
可搬的コードはアンダースコアを含む Fortran 名を使うべきではない．

\code{.Fortran} をコンパイル済み Fortran 9x コードとともに使う際には
注意がいる．特にサブルーチン名が小文字でなかったり，アンダースコアを含む場合，
\R をコンフィギュアした際に使われた Fortran77 コンパイラと
 Fortran 9x コンパイラが異なるかもしれない．
\code{.C} を使い必要なシンボル名の翻訳を自分自身で行うことは
可能である．
}

\section{引数のコピー}{
文字列ベクトルはコンパイル済みコードが呼び出される前にコピーされ，
結果が回収される．
他の原子的ベクトルに対しては，もしそれが呼び出しコード中で使われるなら，
引数はコンパイル済みコードが呼び出される前にコピーされる．

非原子的ベクトルオブジェクトは C コードに対して読み込みオンリーで
決してコピーされない．

この挙動は \code{\link{options}(CBoundsCheck = TRUE)} を設定することで
変更できる．その場合，バイト，論理値，整数そして複素数値ベクトル引数は
コンパイル済みコードを呼び出す前と後の双方でコピーされる．
最初に行われるコピーはガードバイトにより各端まで拡張される．
そして帰途にはそれらが未変更かどうかチェックされる．
 \code{.C} に対しては，文字列ベクトルの各要素はガードバイトを使う．
}

\note{
もしこれらの関数の一つが頻繁に使われるのなら，
\code{PACKAGE} を指定する(検索を一つの DLL に制限するために) か 
\code{.NAME} をネイティブのシンボルオブジェクトとして引き渡す．
シンボルの検索は，特に多くの名前空間が読み込まれている時，長時間かかることがある．

\R にリンクされているシンボルについては \code{PACKAGE = "base"} を
見ることが出来る．これを自分自身のコードで行ってはならない：
そうしたシンボルは API の一部分では無く，警告なしに変更されるかもしれない．
}

\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\seealso{
  \code{\link{dyn.load}}, \code{\link{.Call}}.

  マニュアル \sQuote{Writing R Extensions}.
}
\keyword{programming}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/Foreign.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{Foreign}
%\alias{Foreign}
%\alias{.C}
%\alias{.Fortran}
%\title{Foreign Function Interface}
%\description{
%  Functions to make calls to compiled code that has been loaded into \R.
%}
%\usage{
%       .C(.NAME, \dots, NAOK = FALSE, DUP = TRUE, PACKAGE, ENCODING)
% .Fortran(.NAME, \dots, NAOK = FALSE, DUP = TRUE, PACKAGE, ENCODING)
%}
%\arguments{
%  \item{.NAME}{a character string giving the name of a C function or
%    Fortran subroutine, or an object of class
%    \code{"\link{NativeSymbolInfo}"}, \code{"\link{RegisteredNativeSymbol}"}
%    or \code{"\link{NativeSymbol}"} referring to such a name.}
%  \item{\dots}{arguments to be passed to the foreign function.  Up to 65.}
%  \item{NAOK}{if \code{TRUE} then any \code{\link{NA}} or
%    \code{\link{NaN}} or \code{\link{Inf}} values in the arguments are
%    passed on to the foreign function.  If \code{FALSE}, the presence of
%    \code{NA} or \code{NaN} or \code{Inf} values is regarded as an error.}
%  \item{PACKAGE}{if supplied, confine the search for a character string
%    \code{.NAME} to the DLL given by this argument (plus the
%    conventional extension, \file{.so}, \file{.dll}, \dots).
%
%    This is intended to add safety for packages, which can ensure by
%    using this argument that no other package can override their external
%    symbols, and also speeds up the search (see \sQuote{Note}).}
%
%  \item{DUP, ENCODING}{For back-compatibility, accepted but ignored.}
%}
%
%\details{
%  These functions can be used to make calls to compiled C and Fortran 77
%  code.  Later interfaces are \code{\link{.Call}} and
%  \code{\link{.External}} which are more flexible and have better
%  performance.
%
%  These functions are \link{primitive}, and \code{.NAME} is always
%  matched to the first argument supplied (which should not be named).
%  The other named arguments follow \code{\dots} and so cannot be
%  abbreviated.  For clarity, should avoid using names in the arguments
%  passed to \code{\dots} that match or partially match \code{.NAME}.
%}
%
%\value{
%  A list similar to the \code{\dots} list of arguments passed in
%  (including any names given to the arguments), but reflecting any
%  changes made by the C or Fortran code.
%}
%
%\section{Argument types}{
%  The mapping of the types of \R arguments to C or Fortran arguments is
%
%  \tabular{lll}{
%    \R \tab     C \tab     Fortran\cr
%    integer \tab int * \tab integer\cr
%    numeric \tab double * \tab double precision\cr
%    -- or -- \tab float * \tab real\cr
%    complex \tab Rcomplex * \tab double complex\cr
%    logical \tab int * \tab integer \cr
%    character \tab char ** \tab [see below]\cr
%    raw \tab unsigned char * \tab not allowed\cr
%    list \tab SEXP *\tab not allowed\cr
%    other \tab SEXP\tab not allowed\cr
%  }
%
%  \emph{Note:} The C types corresponding to \code{integer} and
%  \code{logical} are \code{int}, not \code{long} as in S.  This
%  difference matters on most 64-bit platforms, where \code{int} is
%  32-bit and \code{long} is 64-bit (but not on 64-bit Windows).
%
%  \emph{Note:} The Fortran type corresponding to \code{logical} is
%  \code{integer}, not \code{logical}: the difference matters on some
%  Fortran compilers.
%  
%  Numeric vectors in \R will be passed as type \code{double *} to C
%  (and as \code{double precision} to Fortran) unless the argument has
%  attribute \code{Csingle} set to \code{TRUE} (use
%  \code{\link{as.single}} or \code{\link{single}}).  This mechanism is
%  only intended to be used to facilitate the interfacing of existing C
%  and Fortran code.
%
%  The C type \code{Rcomplex} is defined in \file{Complex.h} as a
%  \code{typedef struct {double r; double i;}}.  It may or may not be
%  equivalent to the C99 \code{double complex} type, depending on the
%  compiler used.
%
%  Logical values are sent as \code{0} (\code{FALSE}), \code{1}
%  (\code{TRUE}) or \code{INT_MIN = -2147483648} (\code{NA}, but only if
%  \code{NAOK = TRUE}), and the compiled code should return one of these
%  three values: however non-zero values other than \code{INT_MIN} are
%  mapped to \code{TRUE}.
%
%  Missing (\code{NA}) string values are passed to \code{.C} as the string
%  "NA". As the C \code{char} type can represent all possible bit patterns
%  there appears to be no way to distinguish missing strings from the
%  string \code{"NA"}.  If this distinction is important use \code{\link{.Call}}.
%
%  \code{.Fortran} passes the first (only) character string of a
%  character vector as a C character array to Fortran: that may be usable
%  as \code{character*255} if its true length is passed separately.  Only
%  up to 255 characters of the string are passed back.  (How well this
%  works, and even if it works at all, depends on the C and Fortran
%  compilers and the platform.)
%
%  Lists, functions are other \R objects can (for historical reasons) be
%  passed to \code{.C}, but the \code{\link{.Call}} interface is much
%  preferred.  All inputs apart from atomic vectors should be regarded as
%  read-only, and all apart from vectors (including lists), functions and
%  environments are now deprecated.
%}
%
%\section{Fortran symbol names}{
%  All Fortran compilers known to be usable to compile \R map symbol names
%  to lower case, and so does \code{.Fortran}.
%
%  Symbol names containing underscores are not valid Fortran 77 (although
%  they are valid in Fortran 9x).  Many Fortran 77 compilers will allow
%  them but may translate them in a different way to names not containing
%  underscores.  Such names will often work with \code{.Fortran} (since
%  how they are translated is detected when \R is built and the
%  information used by \code{.Fortran}), but portable code should not use
%  Fortran names containing underscores.
%
%  Use \code{.Fortran} with care for compiled Fortran 9x code: it may not
%  work if the Fortran 9x compiler used differs from the Fortran 77
%  compiler used when configuring \R, especially if the subroutine name
%  is not lower-case or includes an underscore.  It is possible to use
%  \code{.C} and do any necessary symbol-name translation yourself.
%}
%
%\section{Copying of arguments}{
%  Character vectors are copied before calling the compiled code and to
%  collect the results.  For other atomic vectors the argument is copied
%  before calling the compiled code if it is otherwise used in the
%  calling code.
%
%  Non-atomic-vector objects are read-only to the C code and are never
%  copied.
%
%  This behaviour can be changed by setting
%  \code{\link{options}(CBoundsCheck = TRUE)}.  In that case raw,
%  logical, integer, double and complex vector arguments are copied both
%  before and after calling the compiled code.  The first copy made is
%  extended at each end by guard bytes, and on return it is checked that
%  these are unaltered.  For \code{.C}, each element of a character
%  vector uses guard bytes.
%}
%
%\note{
%  If one of these functions is to be used frequently, do specify
%  \code{PACKAGE} (to confine the search to a single DLL) or pass
%  \code{.NAME} as one of the native symbol objects.  Searching for
%  symbols can take a long time, especially when many namespaces are loaded.
%
%  You may see \code{PACKAGE = "base"} for symbols linked into \R.  Do
%  not use this in your own code: such symbols are not part of the API
%  and may be changed without warning.
%}
%
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{dyn.load}}, \code{\link{.Call}}.
%
%  The \sQuote{Writing R Extensions} manual.
%}
%\keyword{programming}
%

\encoding{UTF8}
