% File src/library/base/man/Logic.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{Logic}
\title{Logical Operators}
\usage{
! x
x & y
x && y
x | y
x || y
xor(x, y)

isTRUE(x)
}
\alias{!}
\alias{&}
\alias{&&}
\alias{|}
\alias{||}
\alias{xor}
\alias{Logic}
\alias{isTRUE}
\description{
これらの演算子はバイト型，論理型そして数値風のベクトルに適用される．
}
\arguments{
  \item{x, y}{バイト型もしくは論理型，または \sQuote{数値風} ベクトル(つまり，型 
 \code{\link{double}} (クラス \code{\link{numeric}}), \code{\link{integer}}
 そして \code{\link{complex}}))，もしくはメソッドが存在するオブジェクト．}
}
\details{
  \code{!} は論理否定 (NOT) を意味する．

  \code{&} と \code{&&} は論理積 AND，そして \code{|} と \code{||} 
は論理和 OR を意味する．短い形は算術演算と同じように要素毎に作用する．
長い形は各々のベクトルの最初の要素だけを左から右へ評価する．
評価は結果が定まるまでだけ進行する．
長い形はプログラムの制御フローにふさわしく，
 \code{\link{if}} 文では好ましい．
 
  \code{xor} は論理的排他和を意味する．

  \code{isTRUE(x)} は \code{identical(TRUE, x)} の省略形で，従って 
 \code{x} がその唯一の要素が  \code{TRUE} でいかなる属性(名前すら)も
 持たないの長さ1のベクトルの時，そしてその時だけ真となる．

数値と複素数値は論理値に強制変換され，ゼロは偽ですべてのゼロでない
値は真となる．バイト型ベクトルは  \code{!}, \code{&}, \code{|} そして
 \code{xor} に対していかなる強制変換も無しで処理され，演算はビット毎に
行われる(従って \code{!} は1の補数になる)． 

演算子 \code{!}, \code{&} そして \code{|} は総称的関数である：
それらに対するメソッドを個別に，もしくはグループ総称的
 \code{\link[=S3groupGeneric]{Ops}} (または S4 \code{Logic}，以下を見よ)
に書くことが出来る．(選択がどのように行われるかについては
\code{\link[=S3groupGeneric]{Ops}} を見よ．)

\code{\link{NA}} は適正な論理オブジェクトである．
\code{x} または \code{y} の要素が \code{NA} であると，結果はもし曖昧であれば
 \code{NA} になる．換言すれば \code{NA & TRUE} は 
 \code{NA} と評価されるが，\code{NA & FALSE} は \code{FALSE} と
 評価される．以下の例を見よ．

これらの演算子の優先順序については \link{Syntax} を見よ：
他の多くの言語(S を含む)と異なり AND と OR 演算子は同じ優先度を
持たない(AND 演算子は OR 演算子よりも優先度が高い)．
}
\value{
\code{!} に対しては \code{x} と同じ長さの論理値もしくはバイト型ベクトル
(バイト型 \code{x} に対し)：名前，次元そして次元名，もし強制変換されなければ
他のすべての属性(クラスを含む)は \code{x} からコピーされる．

\code{|}, \code{&} そして \code{xor} に対しては論理値もしくはバイト型ベクトル．
もし長さゼロのベクトルが含まれれば結果は長さゼロを持つ．
さもなければ，短い方のベクトルの要素が必要に応じてリサイクルされる
(もし一部だけがリサイクルされる時は警告が出る)．
結果の属性を決める規則はかなり複雑である．
殆どの属性は長い方の引数から，もし同じ長さなら最初の引数から
取られる．名前はもしそれが結果と同じ長さなら最初から取られ，さもなければ
二番目の引数が同じ長さなら二番目から取られる．
時系列に対しては，こうした操作は系列が両立する時だけ許され，
時系列であるどちらかのクラスと属性 \code{\link{tsp}} (もし双方が時系列なら
同じ時)が使われる．
配列(と配列結果)に対しては次元と次元名は，もし最初の引数が配列なら最初から，
さもなければ二番目から取られる．

\code{||}, \code{&&} と \code{isTRUE} に対しては長さ1の論理値ベクトル．
}
\section{S4 methods}{
  \code{!}, \code{&} そして \code{|} は S4 総称的であり，
後の二つは \code{\link[=S4groupGeneric]{Logic}} グループ総称的
である(従ってメソッドは引数名 \code{e1, e2} を必要とする)．
}
\note{
要素ごとの演算は時折，例えば \sspace{}\code{`&`(x, y)} のような関数として
呼び出される：引数のマッチングがどのように行われるかについては 
\code{\link[base]{Ops}} を見よ．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\seealso{
  \code{\link{TRUE}} または \code{\link{logical}}．

多くのスカラ引数への OR と AND については \code{\link{any}} と \code{\link{all}}．

演算子の優先順序については  \code{\link{Syntax}}．

整数ベクトルのビット毎版に対しては \code{\link{bitwAnd}}．
}
\examples{
y <- 1 + (x <- stats::rpois(50, lambda = 1.5) / 4 - 1)
x[(x > 0) & (x < 1)]    # すべての x 値は 0 と 1 の間
if (any(x == 0) || any(y == 0)) "zero encountered"

## 真偽表を作る :

x <- c(NA, FALSE, TRUE)
names(x) <- as.character(x)
outer(x, x, "&") ## AND 表
outer(x, x, "|") ## OR  表
}
\keyword{logic}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/Logic.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{Logic}
%\title{Logical Operators}
%\usage{
%! x
%x & y
%x && y
%x | y
%x || y
%xor(x, y)
%
%isTRUE(x)
%}
%\alias{!}
%\alias{&}
%\alias{&&}
%\alias{|}
%\alias{||}
%\alias{xor}
%\alias{Logic}
%\alias{isTRUE}
%\description{
%  These operators act on raw, logical and number-like vectors.
%}
%\arguments{
%  \item{x, y}{raw or logical or \sQuote{number-like} vectors (i.e., of types
%    \code{\link{double}} (class \code{\link{numeric}}), \code{\link{integer}}
%    and \code{\link{complex}})), or objects for
%    which methods have been written.}
%}
%\details{
%  \code{!} indicates logical negation (NOT).
%
%  \code{&} and \code{&&} indicate logical AND and \code{|} and \code{||}
%  indicate logical OR.  The shorter form performs elementwise
%  comparisons in much the same way as arithmetic operators.  The longer
%  form evaluates left to right examining only the first element of each
%  vector.  Evaluation proceeds only until the result is determined.  The
%  longer form is appropriate for programming control-flow and typically
%  preferred in \code{\link{if}} clauses.
%
%  \code{xor} indicates elementwise exclusive OR.
%
%  \code{isTRUE(x)} is an abbreviation of \code{identical(TRUE, x)}, and
%  so is true if and only if \code{x} is a length-one logical vector
%  whose only element is \code{TRUE} and which has no attributes (not even
%  names).
%
%  Numeric and complex vectors will be coerced to logical values, with
%  zero being false and all non-zero values being true.  Raw vectors are
%  handled without any coercion for \code{!}, \code{&}, \code{|} and
%  \code{xor}, with these operators being applied bitwise (so \code{!} is
%  the 1s-complement).
%
%  The operators \code{!}, \code{&} and \code{|} are generic functions:
%  methods can be written for them individually or via the
%  \code{\link[=S3groupGeneric]{Ops}} (or S4 \code{Logic}, see below)
%  group generic function.  (See \code{\link[=S3groupGeneric]{Ops}} for
%  how dispatch is computed.)
%
%  \code{\link{NA}} is a valid logical object.  Where a component of
%  \code{x} or \code{y} is \code{NA}, the result will be \code{NA} if the
%  outcome is ambiguous.  In other words \code{NA & TRUE} evaluates to
%  \code{NA}, but \code{NA & FALSE} evaluates to \code{FALSE}.  See the
%  examples below.
%
%  See \link{Syntax} for the precedence of these operators: unlike many
%  other languages (including S) the AND and OR operators do not have the
%  same precedence (the AND operators have higher precedence than the OR
%  operators).
%}
%\value{
%  For \code{!}, a logical or raw vector(for raw \code{x}) of the same
%  length as \code{x}: names, dims and dimnames are copied from \code{x},
%  and all other attributes (including class) if no coercion is done.
%
%  For \code{|}, \code{&} and \code{xor} a logical or raw vector.  If
%  involving a zero-length vector the result has length zero.  Otherwise,
%  the elements of shorter vectors are recycled as necessary (with a
%  \code{\link{warning}} when they are recycled only \emph{fractionally}).
%  The rules for determining the attributes of the result are rather
%  complicated.  Most attributes are taken from the longer argument, the
%  first if they are of the same length.  Names will be copied from the
%  first if it is the same length as the answer, otherwise from the
%  second if that is.  For time series, these operations are allowed only
%  if the series are compatible, when the class and \code{\link{tsp}}
%  attribute of whichever is a time series (the same, if both are) are
%  used.  For arrays (and an array result) the dimensions and dimnames
%  are taken from first argument if it is an array, otherwise the second.
%
%  For \code{||}, \code{&&} and \code{isTRUE}, a length-one logical vector.
%}
%\section{S4 methods}{
%  \code{!}, \code{&} and \code{|} are S4 generics, the latter two part
%  of the \code{\link[=S4groupGeneric]{Logic}} group generic (and
%  hence methods need argument names \code{e1, e2}).
%}
%\note{
%  The elementwise operators are sometimes called as functions as
%  e.g.\sspace{}\code{`&`(x, y)}: see the description of how
%  argument-matching is done in \code{\link[base]{Ops}}.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{TRUE}} or \code{\link{logical}}.
%
%  \code{\link{any}} and \code{\link{all}} for OR and AND on many scalar
%  arguments.
%
%  \code{\link{Syntax}} for operator precedence.
%
%  \code{\link{bitwAnd}} for bitwise versions for integer vectors.
%}
%\examples{
%y <- 1 + (x <- stats::rpois(50, lambda = 1.5) / 4 - 1)
%x[(x > 0) & (x < 1)]    # all x values between 0 and 1
%if (any(x == 0) || any(y == 0)) "zero encountered"
%
%## construct truth tables :
%
%x <- c(NA, FALSE, TRUE)
%names(x) <- as.character(x)
%outer(x, x, "&") ## AND table
%outer(x, x, "|") ## OR  table
%}
%\keyword{logic}
%
%
\encoding{UTF8}
