% File src/library/base/man/Sys.getenv.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{Sys.getenv}
\title{Get Environment Variables}
\description{
  \code{Sys.getenv} は環境変数の値を得る．
}
\usage{
Sys.getenv(x = NULL, unset = "", names = NA)
}
\alias{Sys.getenv}
\arguments{
  \item{x}{文字列ベクトル，または \code{NULL}．}
  \item{unset}{文字列．}
  \item{names}{論理値: 結果に名前を付けるか？ もし \code{NA}
  (既定値) 要素がひとつだけの結果は名前が付かず，複数要素の結果は名前を持つ．}
}
\details{
  どちらの引数も必要なら文字に強制変換される．

 \emph{もし OS が区別するのなら}，設定 \code{unset = NA} は未設定の変数と値 
 \code{""} に設定された変数を区別するようにする.  POSIX
  は OS が区別することを必要とし，すべての既知の \R プラットフォームは区別する．
}
\value{
  \code{x} と同じ長さのベクトルで，(もし \code{names == TRUE} なら)
変数名をその \code{names} 属性として持つ．各要素は対応する \code{x} の
成分により名前がつけられた慣用変数の値を保持する
(もしくは，もしその名前の環境変数が見つからなければ値は \code{unset})．

殆どのプラットフォームでは \code{Sys.getenv()} はすべての環境変数の値を与える
現在のロケールでソートされた名前付きのベクトルを返す．
ある種のプラットフォームでは許されるが POSIX では認められない \code{=} を
含む名前が混乱を与えるかもしれない．
(Windows はそうしたプラットフォームである：
そこでは \code{=} を含む名前は最初の \code{=} の丁度手前で切り詰められる．)

\code{x} が欠損しており \code{names} が偽でない時は，良い
 \code{\link{print}} メソッドを得るためにクラス \code{"Dlist"} を
持つ．
}
\seealso{
  \code{\link{Sys.setenv}},
  使用中のロケールについては \code{\link{Sys.getlocale}}，
 作業ディレクトリについては \code{\link{getwd}}．

  \sQuote{\link{environment variables}} に対するヘルプは \R が使う
多くの環境変数をリストする．
}
\examples{
## HOST が設定されているかどうかはシェル依存，例えば Solaris の csh は未設定．
Sys.getenv(c("R_HOME", "R_PAPERSIZE", "R_PRINTCMD", "HOST"))

names(s <- Sys.getenv()) # すべての設定(値は非常に長いかもしれない)
head(s, 12)#  Dlist print() メソッドを使う

## 言語とロケールの設定 -- しかし Sys.getlocale() を使うほうが良い
s[grep("^L(C|ANG)", names(s))]
}
\keyword{environment}
\keyword{utilities}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/Sys.getenv.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{Sys.getenv}
%\title{Get Environment Variables}
%\usage{
%Sys.getenv(x = NULL, unset = "", names = NA)
%}
%\alias{Sys.getenv}
%\arguments{
%  \item{x}{a character vector, or \code{NULL}.}
%  \item{unset}{a character string.}
%  \item{names}{logical: should the result be named?  If \code{NA} (the
%    default) single-element results are not named whereas multi-element
%    results are.}
%}
%\description{
%  \code{Sys.getenv} obtains the values of the environment variables.
%}
%\details{
%  Both arguments will be coerced to character if necessary.
%
%  Setting \code{unset = NA} will enable unset variables and those set to
%  the value \code{""} to be distinguished, \emph{if the OS does}.  POSIX
%  requires the OS to distinguish, and all known current \R platforms do.
%}
%\value{
%  A vector of the same length as \code{x}, with (if \code{names ==
%  TRUE}) the variable names as its \code{names} attribute.  Each element
%  holds the value of the environment variable named by the corresponding
%  component of \code{x} (or the value of \code{unset} if no environment
%  variable with that name was found).
%
%  On most platforms \code{Sys.getenv()} will return a named vector
%  giving the values of all the environment variables, sorted in the
%  current locale.  It may be confused by names containing \code{=} which
%  some platforms allow but POSIX does not.  (Windows is such a platform:
%  there names including \code{=} are truncated just before the first
%  \code{=}.)
%
%  When \code{x} is missing and \code{names} is not false, the result is
%  of class \code{"Dlist"} in order to get a nice
%  \code{\link{print}} method.
%}
%\seealso{
%  \code{\link{Sys.setenv}},
%  \code{\link{Sys.getlocale}} for the locale in use,
%  \code{\link{getwd}} for the working directory.
%
%  The help for \sQuote{\link{environment variables}} lists many of the
%  environment variables used by \R.
%}
%\examples{
%## whether HOST is set will be shell-dependent e.g. Solaris' csh does not.
%Sys.getenv(c("R_HOME", "R_PAPERSIZE", "R_PRINTCMD", "HOST"))
%
%names(s <- Sys.getenv()) # all settings (the values could be very long)
%head(s, 12)# using the Dlist print() method
%
%## Language and Locale settings -- but rather use Sys.getlocale()
%s[grep("^L(C|ANG)", names(s))]
%}
%\keyword{environment}
%\keyword{utilities}
%
\encoding{UTF8}
