% File src/library/base/man/Sys.which.Rd
% Part of the R package, https://www.R-project.org
% Copyright 2007-2014 R Core Team
% Distributed under GPL 2 or later

\name{Sys.which}
\alias{Sys.which}
\title{Find Full Paths to Executables}
\description{
  これはシステムコマンド \code{which} または Windows ではその
模倣機能へのインタフェイスである．
}
\usage{
Sys.which(names)
}
\arguments{
  \item{names}{可能な実行可能プログラムの名前かパスの文字列．}
}
\details{
  システム命令 \command{which} はシェルによって実行されうるような
実行可能プログラム(実行可能スクリプトを含む)の完全なパス名を
報告する．絶対パスかパスを探す．

Windows では \sQuote{実行可能プログラム} とは拡張子 
 \file{.exe}, \file{.com}, \file{.cmd} または \file{.bat} を
 持つファイルである．そうしたファイルは実際に実行可能である
 必要はないが，\code{\link{system}} はそれらを実行しようと試みる．

Unix 風システムでは \code{which} (普通 \file{/usr/bin/which}) へ
のフルパスが \R をインストールした時に見つけられる．
}
\value{
  \code{names} と同じ長さの文字列ベクトルで，\code{names} で
名前がつけられる．要素は実行可能プログラムへの完全なパスであるか，
その名前の実行可能ファイルが見つからなかったという何らかの指示である．
典型的には指示は \code{""} であるが，これはOSは次第である
(そして既知の例外は \code{""} に変更される)．
\code{names} 中の欠損値は欠損した返り値を持つ(\R 3.0.0 から)．

Windows ではパスは短いパス(8+3 成分で空白なし)で 
 \code{\\} をパス区切りに持つ．
}
\note{
  Windows を除いてこれはシステム命令 \command{which} を
呼び出す．これは例えば POSIX 標準の一部ではないため，
実際は何を実行するかはOS依存である．
普通チルダの展開を行い \command{csh} のエイリアスを利用するかもしれない．

\R 2.x.y では，空白や他のメタ文字を含む引数は
シェルに対するようにエスケープ化される必要があった：
例えば空白を持つ Windows のパスは二重引用符で囲む必要があった．
}
\examples{
## 最初の二つは恐らくどこでも存在する
## texi2dvi は殆どのUnix風システムとMiKTeXの下で存在する
Sys.which(c("ftp", "ping", "texi2dvi", "this-does-not-exist"))
}
\keyword{ utilities }

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/Sys.which.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 2007-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{Sys.which}
%\alias{Sys.which}
%\title{Find Full Paths to Executables}
%\description{
%  This is an interface to the system command \code{which}, or to an
%  emulation on Windows.
%}
%\usage{
%Sys.which(names)
%}
%\arguments{
%  \item{names}{Character vector of names or paths of possible executables.}
%}
%\details{
%  The system command \command{which} reports on the full path names of
%  an executable (including an executable script) as would be executed by
%  a shell, accepting either absolute paths or looking on the path.
%
%  On Windows an \sQuote{executable} is a file with extension
%  \file{.exe}, \file{.com}, \file{.cmd} or \file{.bat}.  Such files need
%  not actually be executable, but they are what \code{\link{system}}
%  tries.
%
%  On a Unix-alike the full path to \code{which} (usually
%  \file{/usr/bin/which}) is found when \R is installed.
%}
%\value{
%  A character vector of the same length as \code{names}, named by
%  \code{names}.  The elements are either the full path to the
%  executable  or some indication that no executable of that name was
%  found.  Typically the indication is \code{""}, but this does depend on
%  the OS (and the known exceptions are changed to \code{""}).  Missing
%  values in \code{names} have missing return values (as from \R 3.0.0).
%
%  On Windows the paths will be short paths (8+3 components, no spaces)
%  with \code{\\} as the path delimiter.
%}
%\note{
%  Except on Windows this calls the system command \command{which}: since
%  that is not part of e.g.\sspace{}the POSIX standards, exactly what it does is
%  OS-dependent.  It will usually do tilde-expansion and it may make use
%  of \command{csh} aliases.
%
%  In \R 2.x.y, arguments containing spaces or other metacharacters
%  needed to be escaped as they would be for a shell: for example Windows
%  paths containing spaces needed to be enclosed in double quotes.
%}
%\examples{
%## the first two are likely to exist everywhere
%## texi2dvi exists on most Unix-alikes and under MiKTeX
%Sys.which(c("ftp", "ping", "texi2dvi", "this-does-not-exist"))
%}
%\keyword{ utilities }
%
\encoding{UTF8}
