% File src/library/base/man/char.expand.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2008 R Core Team
% Distributed under GPL 2 or later

\name{char.expand}
\alias{char.expand}
\title{Expand a String with Respect to a Target Table}
\usage{char.expand(input, target, nomatch = stop("no match"))}
\description{
  その最初の引数にユニークにマッチするするものを二番目の引数の要素中から探す．
  もし見つかればその要素が返される；さもなければ三番目の引数で
  指定される行動を行う．
}
\arguments{
  \item{input}{拡張されるべき文字列．}
  \item{target}{マッチが探されるべき値の文字列ベクトル．}
  \item{nomatch}{拡張が不可能なときに評価されるべき \R 表現式．}
}
\details{
  この関数は関数引数に省略が許される時に特に有用であり，
  可能な値の目標デーブルに関してユニークに拡大される必要がある．
}
\value{
  長さ1の文字列ベクトルで \code{target} の要素の一つ
  (\code{nomatch} がエラー無しと変更されない限り，そしてその時は
   長さがゼロの文字列であっても良い)．
}
\seealso{
  部分的な文字列のマッチングには \code{\link{charmatch}} と \code{\link{pmatch}}．
}
\examples{
locPars <- c("mean", "median", "mode")
char.expand("me", locPars, warning("Could not expand!"))
char.expand("mo", locPars)
}
\keyword{character}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/char.expand.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2008 R Core Team
%% Distributed under GPL 2 or later
%
%\name{char.expand}
%\alias{char.expand}
%\title{Expand a String with Respect to a Target Table}
%\usage{char.expand(input, target, nomatch = stop("no match"))}
%\description{
%  Seeks a unique match of its first argument among the
%  elements of its second.  If successful, it returns this element;
%  otherwise, it performs an action specified by the third argument.
%}
%\arguments{
%  \item{input}{a character string to be expanded.}
%  \item{target}{a character vector with the values to be matched
%    against.}
%  \item{nomatch}{an \R expression to be evaluated in case expansion was
%    not possible.}
%}
%\details{
%  This function is particularly useful when abbreviations are allowed in
%  function arguments, and need to be uniquely expanded with respect to a
%  target table of possible values.
%}
%\value{
%  A length-one character vector, one of the elements of \code{target}
%  (unless \code{nomatch} is changed to be a non-error, when it can be a
%  zero-length character string).
%}
%\seealso{
%  \code{\link{charmatch}} and \code{\link{pmatch}} for performing
%  partial string matching.
%}
%\examples{
%locPars <- c("mean", "median", "mode")
%char.expand("me", locPars, warning("Could not expand!"))
%char.expand("mo", locPars)
%}
%\keyword{character}
%
\encoding{UTF8}
