% File src/library/base/man/chol2inv.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{chol2inv}
\alias{chol2inv}
\title{Inverse from Choleski (or QR) Decomposition}
\description{
  対称正定値正方行列の逆行列をそのコレスキ分解から求める．
  同じことだが \eqn{(X'X)^{-1}}{(X'X)^(-1)} を \eqn{X} の
  QR 分解の(\eqn{R} 部分)から計算する．
}
\usage{
chol2inv(x, size = NCOL(x), LINPACK = FALSE)
}
\arguments{
  \item{x}{行列．最初の \code{size} 個の列の上三角部分は分解されるべき
    行列のコレスキ分解を含む．}
  \item{size}{コレスキ分解を含む \code{x} の列数．}
  \item{LINPACK}{論理値．廃止され無視される(真の値に対する警告と共に)．}

}
\value{
  そのコレスキ分解が与えられた行列の逆行列．

  基礎にある LAPACK コードからの不成功の結果は正のエラーコードを与える
  エラーになる：これらは FORTRAN コードの詳細な検討によってのみ
  解釈できる．
}
\source{
  これは LAPACK ルーチン \code{DPOTRI} へのインタフェイスである．
  LAPACK は \url{http://www.netlib.org/lapack} にあり，そのガイドは
  参考文献にある．
}
\references{
  Anderson. E. and ten others (1999)
  \emph{LAPACK Users' Guide}. Third Edition.
  SIAM.

  \url{http://www.netlib.org/lapack/lug/lapack_lug.html} でオンラインで入手可能．

  Dongarra, J. J., Bunch, J. R., Moler, C. B. and Stewart, G. W. (1978)\cr
  \emph{LINPACK Users Guide}.
  Philadelphia: SIAM Publications.
}
\seealso{
  \code{\link{chol}}, \code{\link{solve}}.
}
\examples{
cma <- chol(ma  <- cbind(1, 1:3, c(1,3,7)))
ma \%*\% chol2inv(cma)
}
\keyword{algebra}
\keyword{array}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/chol2inv.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{chol2inv}
%\alias{chol2inv}
%\title{Inverse from Choleski (or QR) Decomposition}
%\description{
%  Invert a symmetric, positive definite square matrix from its Choleski
%  decomposition.  Equivalently, compute \eqn{(X'X)^{-1}}{(X'X)^(-1)}
%  from the (\eqn{R} part) of the QR decomposition of \eqn{X}.
%}
%\usage{
%chol2inv(x, size = NCOL(x), LINPACK = FALSE)
%}
%\arguments{
%  \item{x}{a matrix.  The first \code{size} columns of the upper triangle
%    contain the Choleski decomposition of the matrix to be inverted.}
%  \item{size}{the number of columns of \code{x} containing the
%    Choleski decomposition.}
%  \item{LINPACK}{logical.  Defunct and ignored (with a warning for true value).}
%
%}
%\value{
%  The inverse of the matrix whose Choleski decomposition was given.
%
%  Unsuccessful results from the underlying LAPACK code will result in an
%  error giving a positive error code: these can only be interpreted by
%  detailed study of the FORTRAN code.
%}
%\source{
%  This is an interface to the LAPACK routine \code{DPOTRI}.
%  LAPACK is from \url{http://www.netlib.org/lapack} and its guide is listed
%  in the references.
%}
%\references{
%  Anderson. E. and ten others (1999)
%  \emph{LAPACK Users' Guide}. Third Edition.
%  SIAM.
%  Available on-line at
%  \url{http://www.netlib.org/lapack/lug/lapack_lug.html}.
%
%  Dongarra, J. J., Bunch, J. R., Moler, C. B. and Stewart, G. W. (1978)
%  \emph{LINPACK Users Guide}.
%  Philadelphia: SIAM Publications.
%}
%\seealso{
%  \code{\link{chol}}, \code{\link{solve}}.
%}
%\examples{
%cma <- chol(ma  <- cbind(1, 1:3, c(1,3,7)))
%ma \%*\% chol2inv(cma)
%}
%\keyword{algebra}
%\keyword{array}
%
\encoding{UTF8}
