% File src/library/base/man/crossprod.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{crossprod}
\alias{crossprod}
\alias{tcrossprod}
\title{Matrix Crossproduct}
\description{
  引数として行列 \code{x} と \code{y} をあたえた時，行列のクロス積を返す．
  これは形式的には呼び出し \code{t(x) \%*\% y}
  (\code{crossprod}) 又は \code{x \%*\% t(y)} (\code{tcrossprod})
  に等しい(が少し速い)．
}
\usage{
crossprod(x, y = NULL)

tcrossprod(x, y = NULL)
}
\arguments{
  \item{x, y}{数値又は複素数値行列(又はベクトル)： \code{y = NULL}
    は \code{x} と同じ行列とされる．文脈に応じてベクトルは1行又は
    1列の行列と見做される．}
}
\value{
  倍精度実数又は複素数行列で，\code{x} と \code{y} から
  取られた適当な \code{dimnames} を持つ．
}
\note{
  \code{x} や \code{y} が行列でなければ，1列又は1行だけの行列として
  扱われるが，それらの \code{\link{names}} は普通 
  \code{\link{dimnames}} に使われない．従って現在最後の例は空の
  次元名を持つ．

  \R 3.2.0 以来，同じ状況ではこれらの行列積(また \code{\link{\%*\%}})は
  ベクトルを同じ列又は行だけの行列により柔軟に変えるのでより多くの
  ケースが許される．
}

\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\seealso{
  \code{\link{\%*\%}} と外積 \code{\link{\%o\%}}．
}
\examples{
(z <- crossprod(1:4))    # = sum(1 + 2^2 + 3^2 + 4^2)
drop(z)                  # スカラ
x <- 1:4; names(x) <- letters[1:4]; x
tcrossprod(as.matrix(x)) # is
identical(tcrossprod(as.matrix(x)),
          crossprod(t(x)))
tcrossprod(x)            # 次元名なし

m <- matrix(1:6, 2,3) ; v <- 1:3; v2 <- 2:1
stopifnot(identical(tcrossprod(v, m), v \%*\% t(m)),
          identical(tcrossprod(v, m), crossprod(v, t(m))),
          identical(crossprod(m, v2), t(m) \%*\% v2))
}
\keyword{algebra}
\keyword{array}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/crossprod.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{crossprod}
%\alias{crossprod}
%\alias{tcrossprod}
%\title{Matrix Crossproduct}
%\description{
%  Given matrices \code{x} and \code{y} as arguments, return a matrix
%  cross-product.  This is formally equivalent to (but usually slightly
%  faster than) the call \code{t(x) \%*\% y} (\code{crossprod}) or
%  \code{x \%*\% t(y)} (\code{tcrossprod}).
%}
%\usage{
%crossprod(x, y = NULL)
%
%tcrossprod(x, y = NULL)
%}
%\arguments{
%  \item{x, y}{numeric or complex matrices (or vectors): \code{y = NULL}
%    is taken to be the same matrix as \code{x}.  Vectors are promoted to
%    single-column or single-row matrices, depending on the context.}
%}
%\value{
%  A double or complex matrix, with appropriate \code{dimnames} taken
%  from \code{x} and \code{y}.
%}
%\note{
%  When \code{x} or \code{y} are not matrices, they are treated as column or
%  row matrices, but their \code{\link{names}} are usually \bold{not}
%  promoted to \code{\link{dimnames}}.  Hence, currently, the last
%  example has empty dimnames.
%
%  In the same situation, these matrix products (also \code{\link{\%*\%}})
%  are more flexible in promotion of vectors to row or column matrices, such
%  that more cases are allowed, since \R 3.2.0.
%}
%%% Consider using a new optional argument, say 'make.names = NA'
%%% {as in kronecker} with possible values  FALSE / NA / TRUE  where
%%% FALSE gives empty dimnames; NA = current behavior; TRUE gives "as much as sensible"
%
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{\%*\%}} and outer product \code{\link{\%o\%}}.
%}
%\examples{
%(z <- crossprod(1:4))    # = sum(1 + 2^2 + 3^2 + 4^2)
%drop(z)                  # scalar
%x <- 1:4; names(x) <- letters[1:4]; x
%tcrossprod(as.matrix(x)) # is
%identical(tcrossprod(as.matrix(x)),
%          crossprod(t(x)))
%tcrossprod(x)            # no dimnames
%
%m <- matrix(1:6, 2,3) ; v <- 1:3; v2 <- 2:1
%stopifnot(identical(tcrossprod(v, m), v \%*\% t(m)),
%          identical(tcrossprod(v, m), crossprod(v, t(m))),
%          identical(crossprod(m, v2), t(m) \%*\% v2))
%}
%\keyword{algebra}
%\keyword{array}
%
\encoding{UTF8}
