% File src/library/base/man/cut.POSIXt.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{cut.POSIXt}
\alias{cut.POSIXt}
\alias{cut.Date}
\title{Convert a Date or Date-Time Object to a Factor}
\description{
  暦日・時刻オブジェクトに適用される \code{\link{cut}} のメソッド．
}
\usage{
\method{cut}{POSIXt}(x, breaks, labels = NULL, start.on.monday = TRUE,
    right = FALSE, \dots)

\method{cut}{Date}(x, breaks, labels = NULL, start.on.monday = TRUE,
    right = FALSE, \dots)
}
\arguments{
  \item{x}{クラス \code{"POSIXt"} か \code{"Date"} を継承するオブジェクト．}
  \item{breaks}{
    分点のベクトル，又は \code{x} が仕分けされる区間数を与える数，
    又は区間の指定で \code{"sec"}, \code{"min"}, \code{"hour"},
    \code{"day"}, \code{"DSTday"}, \code{"week"},
    \code{"month"}, \code{"quarter"} 又は \code{"year"} でオプションで
    整数化空白が先頭に付くか \code{"s"} が後に付く．
    (\code{"Date"} オブジェクトに対しては区間指定
    \code{"day"}, \code{"week"}, \code{"month"}, \code{"quarter"} そして
    \code{"year"} だけが許される．)
  }
  \item{labels}{
    結果のカテゴリーの水準のラベル．既定では，
    ラベルは区間の左端から作られる
    (これは既定値 \code{right} ではその区間に入る)．もし
    \code{labels = FALSE} ならば，因子の代わりに単純な整数コードが
    返される．
  }
  \item{start.on.monday}{論理値．もし \code{breaks = "weeks"} ならば，
    一週間は月曜日に始まるか日曜日に始まるか?}
  \item{right, \dots}{他のメソッドに・から引き渡される引数．}
}
\details{
  \code{right} に対する既定動作は既定メソッドとは
  異なることを注意する．
  \code{include.lowest = TRUE} の使用は日付範囲両端を含める．

  \code{breaks = "quarter"} は3ヶ月毎の区間を作る．
  必要に応じて1月1日，4月1日，7月1日又は10月1日(\code{min(x)} に基づく)
  から始まる．

  ベクトル \code{breaks} は使用前にソートされる：
  \code{labels} はソートされたベクトルに対応すべきである．
}
\value{
   \code{labels = FALSE} でない限り因子が返される．
   \code{labels = FALSE} ならば整数の水準コード．
  
   \code{breaks} の範囲外に入る値は \code{NA} 値を持つため \code{NA}
   とコードされる．
}
\seealso{
  \code{\link{seq.POSIXt}}, \code{\link{seq.Date}}, \code{\link{cut}}
}
\examples{
## 10週周期のランダムデータ
cut(ISOdate(2001, 1, 1) + 70*86400*stats::runif(100), "weeks")
cut(as.Date("2001/1/1") + 70*stats::runif(100), "weeks")

# 標準はすべて真夜中が一日の始めとするが
# それを前日の最後と解釈する人もいる ...
tm <- seq(as.POSIXct("2012-06-01 06:00"), by = "6 hours", length.out = 24)
aggregate(1:24, list(day = cut(tm, "days")), mean)
# 真夜中を前日に含むバージョン：
aggregate(1:24, list(day = cut(tm, "days", right = TRUE)), mean)
}
\keyword{manip}
\keyword{chron}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/cut.POSIXt.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{cut.POSIXt}
%\alias{cut.POSIXt}
%\alias{cut.Date}
%\title{Convert a Date or Date-Time Object to a Factor}
%\description{
%  Method for \code{\link{cut}} applied to date-time objects.
%}
%\usage{
%\method{cut}{POSIXt}(x, breaks, labels = NULL, start.on.monday = TRUE,
%    right = FALSE, \dots)
%
%\method{cut}{Date}(x, breaks, labels = NULL, start.on.monday = TRUE,
%    right = FALSE, \dots)
%}
%\arguments{
%  \item{x}{an object inheriting from class \code{"POSIXt"} or \code{"Date"}.}
%  \item{breaks}{
%    a vector of cut points \emph{or} number giving the number of
%    intervals which \code{x} is to be cut into \emph{or} an
%    interval specification, one of \code{"sec"}, \code{"min"},
%    \code{"hour"}, \code{"day"}, \code{"DSTday"}, \code{"week"},
%    \code{"month"}, \code{"quarter"} or \code{"year"}, optionally
%    preceded by an integer and a space, or followed by \code{"s"}.
%    (For \code{"Date"} objects only interval specifications using
%    \code{"day"}, \code{"week"}, \code{"month"}, \code{"quarter"} and
%    \code{"year"} are allowed.)
%  }
%  \item{labels}{
%    labels for the levels of the resulting category.  By default,
%    labels are constructed from the left-hand end of the intervals
%    (which are included for the default value of \code{right}).  If
%    \code{labels = FALSE}, simple integer codes are returned instead
%    of a factor.
%  }
%  \item{start.on.monday}{logical.  If \code{breaks = "weeks"}, should the
%    week start on Mondays or Sundays?}
%  \item{right, \dots}{arguments to be passed to or from other methods.}
%}
%\details{
%  Note that the default for \code{right} differs from the
%  \link[=cut.default]{default method}.  Using \code{include.lowest =
%    TRUE} will include both ends of the range of dates.
%
%  Using \code{breaks = "quarter"} will create intervals of 3 calendar
%  months, with the intervals beginning on January 1, April 1,
%  July 1 or October 1 (based upon \code{min(x)}) as appropriate.
%
%  A vector of \code{breaks} will be sorted before use: \code{labels} should
%  correspond to the sorted vector.
%}
%\value{
%  A factor is returned, unless \code{labels = FALSE} which returns
%  the integer level codes.
%  
%  Values which fall outside the range of \code{breaks} are coded as
%  \code{NA}, as are and \code{NA} values.
%}
%\seealso{
%  \code{\link{seq.POSIXt}}, \code{\link{seq.Date}}, \code{\link{cut}}
%}
%\examples{
%## random dates in a 10-week period
%cut(ISOdate(2001, 1, 1) + 70*86400*stats::runif(100), "weeks")
%cut(as.Date("2001/1/1") + 70*stats::runif(100), "weeks")
%
%# The standards all have midnight as the start of the day, but some
%# people incorrectly interpret it at the end of the previous day ...
%tm <- seq(as.POSIXct("2012-06-01 06:00"), by = "6 hours", length.out = 24)
%aggregate(1:24, list(day = cut(tm, "days")), mean)
%# and a version with midnight included in the previous day:
%aggregate(1:24, list(day = cut(tm, "days", right = TRUE)), mean)
%}
%\keyword{manip}
%\keyword{chron}
%
\encoding{UTF8}
