% File src/library/base/man/dump.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{dump}
\title{Text Representations of R Objects}
\usage{
dump(list, file = "dumpdata.R", append = FALSE,
     control = "all", envir = parent.frame(), evaluate = TRUE)
}
\alias{dump}
\description{
  この関数は \R オブジェクトの名前からそのテキスト表現をファイルもしくは
  コネクションに作る．
  \code{dump} によるファイルは通常他の \R セッションで読み込み実行できる．
}
\arguments{
  \item{list}{文字列ベクトル．書き込まれるべき一つもしくは複数の \R オブジェクトの名前．}

  \item{file}{ファイルかコネクションの名前である文字列．
    \code{""} はコンソールを指示する．}

  \item{append}{もし \code{TRUE} で \code{file} が文字列ならば，
    出力は \code{file} に追加される；さもなければ \code{file} の内容は
    上書きされる．}

  \item{control}{逆構文解析のオプションを指示する文字列ベクトル．
    \code{\link{.deparseOpts}} にそれらの説明がある．}

  \item{envir}{オブジェクトを探すべき環境．}

  \item{evaluate}{論理値．予約を評価すべきか?}
}
\details{
  もし名前のオブジェクトの幾つかが(スコープ中に)存在しなければ，
  それらは無視され警告が出る．もし \code{file} がファイルでオブジェクトが
  存在しなければファイルは生成されない．

  読み込み実行は \code{dump} されたオブジェクトと同一のコピーを作らないかもしれない．
  もし問題が起きそうなら警告が出る．
  例えば特異なオブジェクトや複雑なオブジェクトの場合である
  (注意を見よ)．

  期待されるよりも少ない文字がファイルに書き込まれた場合は警告が出る．
  これはファイルシステムが一杯であるか破損していることを意味するかもしれない．

  \code{dump} で書込されたファイルは別の \R セッションで \code{\link{source}} 関数で
  読み込み実行できるが，関数 \code{\link{save}} は \R データの移動用に
  デザインされており，\code{dump} が扱えない \R オブジェクトでも処理できる．
  最大の復元可能性のためには
  \code{control = c("all", "hexNumeric")} を使う．

  オブジェクトのより可読性の高い表現を得るためには
  \code{control = NULL} を使おう．これは属性を無視し，
  \code{source} された時同一のコピーを作り出す可能性が減少するような
  単純化を行う．
  詳細は \code{\link{deparse}} を見よ．

  保存されたソースの表示ではなく関数の内部表現を逆構文解析するには\cr
  \code{control = c("keepInteger", "warnIncomplete", "keepNA")} を使う．
  これはすべての整形とコメントを無くすが，保存されたソースが
  最早正確ではない時に役に立つかもしれない．
  
  普通ユーザが予約に遭遇するのは，遅延読み込みの結果
  (既定の \code{evaluate = TRUE} が本質的な時)としてと，
  \code{evaluate = FALSE} が意図されていたかもしれない時の
   \code{\link{delayedAssign}} の後だけである．
}
\value{
  書き込みされたオブジェクトの名前を含む不可視の文字列ベクトル．
}
\note{
  \code{dump} は基本名前空間中で定義されているので，\code{dump} が
  トップレベルのプロンプトから呼び出されるか \code{envir} 引数が明示的に
  与えられていない限り，パッケージ \pkg{base}
  が大局的環境より先に調べられる．

  ソース属性が実際の関数定義と動機されないリスクを避けるため，
  関数のソース属性は決して属性としては書き込まれない．

  現在の所環境，外部ポインター，弱参照そして型 \code{S4} のオブジェクトは
  \code{source} 関数で読み込み実行できるような仕方では逆構文解析されない．
  加えて言語オブジェクトは \code{control} の値が何であろうとも単純な仕方で
  逆構文解析され，これはそれらの属性を書き込まないことを含む
  (警告が出る)．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}

\seealso{
  \R オブジェクトのより信頼できる保存方法は \code{\link{dput}}, \code{\link{dget}},
  \code{\link{write}}.\cr
  \code{\link{save}}．
}
\examples{
x <- 1; y <- 1:10
dump(ls(pattern = '^[xyz]'), "xyz.Rdmped")
print(.Last.value)
unlink("xyz.Rdmped")
}
\keyword{file}
\keyword{connection}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/dump.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{dump}
%\title{Text Representations of R Objects}
%\usage{
%dump(list, file = "dumpdata.R", append = FALSE,
%     control = "all", envir = parent.frame(), evaluate = TRUE)
%}
%\alias{dump}
%\description{
%  This function takes a vector of names of \R objects and produces
%  text representations of the objects on a file or connection.
%  A \code{dump} file can usually be \code{\link{source}}d into another
%  \R session.
%}
%\arguments{
%  \item{list}{character vector.  The names of one or more \R objects to be dumped.}
%
%  \item{file}{either a character string naming a file or a
%    \link{connection}.  \code{""} indicates output to the console.}
%
%  \item{append}{if \code{TRUE} and \code{file} is a character string,
%    output will be appended to \code{file}; otherwise, it will overwrite
%    the contents of \code{file}.}
%
%  \item{control}{character vector indicating deparsing options.
%    See \code{\link{.deparseOpts}} for their description.}
%
%  \item{envir}{the environment to search for objects.}
%
%  \item{evaluate}{logical.  Should promises be evaluated?}
%}
%\details{
%  If some of the objects named do not exist (in scope), they are
%  omitted, with a warning.  If \code{file} is a file and no objects
%  exist then no file is created.
%
%  \code{source}ing may not produce an identical copy of
%  \code{dump}ed objects.  A warning is issued if it is likely that
%  problems will arise, for example when dumping exotic or complex
%  objects (see the Note).
%
%  \code{dump} will also warn if fewer characters were written to a file
%  than expected, which may indicate a full or corrupt file system.
%
%  A \code{dump} file can be \code{\link{source}}d into another \R (or
%  perhaps S) session, but the function \code{\link{save}} is designed to
%  be used for transporting \R data, and will work with \R objects that
%  \code{dump} does not handle.  For maximal reproducibility use
%  \code{control = c("all", "hexNumeric")}.
%
%  To produce a more readable representation of an object, use
%  \code{control = NULL}.  This will skip attributes, and will make other
%  simplifications that make \code{source} less likely to produce an
%  identical copy.  See \code{\link{deparse}} for details.
%
%  To deparse the internal representation of a function rather than
%  displaying the saved source, use \code{control = c("keepInteger",
%    "warnIncomplete", "keepNA")}.  This will lose all formatting and
%  comments, but may be useful in those cases where the saved source is
%  no longer correct.
%  
%  Promises will normally only be encountered by users as a result of
%  lazy-loading (when the default \code{evaluate = TRUE} is essential)
%  and after the use of \code{\link{delayedAssign}},
%  when \code{evaluate = FALSE} might be intended.
%}
%\value{
%  An invisible character vector containing the names of the objects
%  which were dumped.
%}
%\note{
%  As \code{dump} is defined in the base namespace, the \pkg{base}
%  package will be searched \emph{before} the global environment unless
%  \code{dump} is called from the top level prompt or the \code{envir}
%  argument is given explicitly.
%
%  To avoid the risk of a source attribute becoming out of sync with the
%  actual function definition, the source attribute of a function will
%  never be dumped as an attribute.
%
%  Currently environments, external pointers, weak references and objects
%  of type \code{S4} are not deparsed in a way that can be
%  \code{source}d.  In addition, \link{language objects} are deparsed in a
%  simple way whatever the value of \code{control}, and this includes not
%  dumping their attributes (which will result in a warning).
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%
%\seealso{
%  \code{\link{dput}}, \code{\link{dget}}, \code{\link{write}}.\cr
%  \code{\link{save}} for a more reliable way to save \R objects.
%}
%\examples{
%x <- 1; y <- 1:10
%dump(ls(pattern = '^[xyz]'), "xyz.Rdmped")
%print(.Last.value)
%unlink("xyz.Rdmped")
%}
%\keyword{file}
%\keyword{connection}
%
\encoding{UTF8}
