% File src/library/base/man/file.path.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{file.path}
\alias{file.path}
\title{Construct Path to File}
\description{
  プラットフォームに依存した形式で部分からファイルへのパスを構成する．
}
\usage{
file.path(\dots, fsep = .Platform$file.sep)
}
\arguments{
  \item{\dots}{文字列．}
  \item{fsep}{使用するパス分離記号．}
}
\details{
  この関数は \R 自体で徹底的に使われるため速度重視で実装されている
  (\code{\link{paste}} より速い)．

  これはまた \code{fsep = .Platform$path.sep} として \env{PATH} と 
  \env{R_LIBS} のような環境へのパスにも使われる．

  Windows ファイルに対しては
  \file{/} と \file{d:/} を除いては末尾のパス分離記号は不正である
  (しかしながらある種の関数/ユーティリティーはそれらを受け入れる)．
  従って \R 3.1.0 以来末尾の \code{/} や \code{\\} は取り除かれる．
}
\value{
  もしすべての引数が正の長さを持てば \code{fsep} で分離して引数を項毎に結合して
  得られる文字列．さもなければ空の文字列(\code{\link{paste}} とは異なり)．
}
\note{
  Windows では成分は既定では \code{/} で分離される
  (\code{\\} ではない)．
}
\keyword{file}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/file.path.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{file.path}
%\alias{file.path}
%\title{Construct Path to File}
%\description{
%  Construct the path to a file from components in a platform-independent
%  way.
%}
%\usage{
%file.path(\dots, fsep = .Platform$file.sep)
%}
%\arguments{
%  \item{\dots}{character vectors.}
%  \item{fsep}{the path separator to use.}
%}
%\details{
%  The implementation is designed to be fast (faster than
%  \code{\link{paste}}) as this function is used extensively in \R itself.
%
%  It can also be used for environment paths such as \env{PATH} and
%  \env{R_LIBS} with \code{fsep = .Platform$path.sep}.
%
%  Trailing path separators are invalid for Windows file paths apart from
%  \file{/} and \file{d:/} (although some functions/utilities do accept
%  them), so as from \R 3.1.0 a trailing \code{/} or \code{\\} is
%  removed.
%}
%\value{
%  A character vector of the arguments concatenated term-by-term and
%  separated by \code{fsep} if all arguments have positive length;
%  otherwise, an empty character vector (unlike \code{\link{paste}}).
%}
%\note{
%  The components are by default separated by \code{/}
%  (not \code{\\}) on Windows.
%}
%\keyword{file}
%
\encoding{UTF8}
