% File src/library/base/man/getwd.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2011 R Core Team
% Distributed under GPL 2 or later

\name{getwd}
\alias{getwd}
\alias{setwd}
\title{Get or Set Working Directory}
\usage{
getwd()
setwd(dir)
}
\arguments{
  \item{dir}{文字列；チルド展開が行われる．}
}
\description{
  \code{getwd} は \R プロセスの現在の作業ディレクトリを
  表す絶対ファイルパスを返す；\code{setwd(dir)} は作業ディレクトリを
  \code{dir} に設定する．
}
\note{
  返り値は\strong{一つの}絶対ファイルパスである：
  ディレクトリへのパスの表現式は複数あり得，ある種の OS では返り値は
  ディレクトリを変更しまた同じディレクトリに戻っても異なることがあり得る
  (例えばシンボリックリンクを横切った場合)．
}

\seealso{
  ディレクトリの内容には \code{\link{list.files}}．

  \sQuote{標準的}なパス名には \code{\link{normalizePath}}．
}

\value{
  \code{getwd} は文字列か，もし作業ディレクトリが利用できなければ \code{NULL} を
  返す．Windows では返り値のパスは分離記号をとして \code{/} を使い
  UTF-8 でエンコードされる．パスはそれがルートディレクトリ
  (Windows ではドライブかシェア)でない限り末尾に \code{/} を持たない．

  \code{setwd} は変更前に現在のディレクトリを返す．
  不可視であり \code{getwd} と同じ慣例を持つ．
  それはもし不成功であれば(未実装の場合を含む)エラーを返す．
}

\examples{
(WD <- getwd())
if (!is.null(WD)) setwd(WD)
}
\keyword{utilities}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/getwd.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2011 R Core Team
%% Distributed under GPL 2 or later
%
%\name{getwd}
%\alias{getwd}
%\alias{setwd}
%\title{Get or Set Working Directory}
%\usage{
%getwd()
%setwd(dir)
%}
%\arguments{
%  \item{dir}{A character string: \link{tilde expansion} will be done.}
%}
%\description{
%  \code{getwd} returns an absolute filepath representing the current
%  working directory of the \R process; \code{setwd(dir)} is used to set
%  the working directory to \code{dir}.
%}
%\note{
%  Note that the return value is said to be \strong{an} absolute
%  filepath: there can be more than one representation of the path to a
%  directory and on some OSes the value returned can differ after
%  changing directories and changing back to the same directory (for
%  example if symbolic links have been traversed).
%}
%
%\seealso{
%  \code{\link{list.files}} for the \emph{contents} of a directory.
%
%  \code{\link{normalizePath}} for a \sQuote{canonical} path name.
%}
%
%\value{
%  \code{getwd} returns a character string or \code{NULL} if the working
%  directory is not available.
%  On Windows the path returned will use \code{/} as the path separator
%  and be encoded in UTF-8.  The path will not have a trailing \code{/}
%  unless it is the root directory (of a drive or share on Windows).
%
%  \code{setwd} returns the current directory before the change,
%  invisibly and with the same conventions as \code{getwd}.  It will give
%  an error if it does not succeed (including if it is not implemented).
%}
%
%\examples{
%(WD <- getwd())
%if (!is.null(WD)) setwd(WD)
%}
%\keyword{utilities}
%
\encoding{UTF8}
