% File src/library/base/man/hexmode.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{hexmode}
\alias{as.hexmode}
\alias{format.hexmode}
\alias{print.hexmode}
\alias{as.character.hexmode}
\alias{[.hexmode}
\alias{!.hexmode}
\alias{|.hexmode}
\alias{&.hexmode}
\alias{xor.hexmode}
\alias{hexmode}
\title{Display Numbers in Hexadecimal}
\description{
  整数を16進法書式に変換したりプリントしたりする．
  最大値を表示するのに必要な桁数を用い，必要なら先頭にゼロを加える．
}
\usage{
as.hexmode(x)

\method{as.character}{hexmode}(x, \dots)

\method{format}{hexmode}(x, width = NULL, upper.case = FALSE, \dots)

\method{print}{hexmode}(x, \dots)
}
\arguments{
  \item{x}{クラス \code{"hexmode"} を継承するメソッドに対するオブジェクト．}
  \item{width}{\code{NULL} 又は使用する最小幅を指定する正整数．
    先頭はゼロで埋められる．}
  \item{upper.case}{大文字を使うか小文字を使うかを指示する論理値．}
  \item{\dots}{他のメソッドに・へ渡される追加引数．}
}
\details{
  クラス \code{"hexmode"} はその属性を持つ整数ベクトルからなり，
  単にそれらが16進数でプリントされることを保証するのに使われる．

  もし \code{width = NULL} (既定)ならば，出力はすべての欠損していない要素
  に対して必要な最小の幅になるように先頭がゼロで埋められる．

  \code{as.hexmode} は整数(型が \code{"integer"} か \code{"double"}) と
  要素が \code{0-9}, \code{a-f}, \code{A-F} (又は \code{NA}) だけを含む
  文字列をクラス \code{"hexmode"} に変換できる．

  メソッド \code{\link{!}}, \code{\link{|}}, \code{\link{&}} そして
  \code{\link{xor}} が存在する：これらはその引数を最長の長さまで
  リサイクルし，それから各要素にビットごとに適用される．
}
\seealso{
  整数を16進数に変換する他のオプションについては \code{\link{octmode}}, \code{\link{sprintf}}，
  16進文字列を整数に変換するには \code{\link{strtoi}}．
}
\examples{
i <- as.hexmode("7fffffff")
i; class(i)
identical(as.integer(i), .Machine$integer.max)

hm <- as.hexmode(c(NA, 1)); hm
as.integer(hm)
}
\keyword{utilities}
\keyword{print}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/hexmode.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{hexmode}
%\alias{as.hexmode}
%\alias{format.hexmode}
%\alias{print.hexmode}
%\alias{as.character.hexmode}
%\alias{[.hexmode}
%\alias{!.hexmode}
%\alias{|.hexmode}
%\alias{&.hexmode}
%\alias{xor.hexmode}
%\alias{hexmode}
%\title{Display Numbers in Hexadecimal}
%\description{
%  Convert or print integers in hexadecimal format, with as many digits
%  as are needed to display the largest, using leading zeroes as
%  necessary.
%}
%\usage{
%as.hexmode(x)
%
%\method{as.character}{hexmode}(x, \dots)
%
%\method{format}{hexmode}(x, width = NULL, upper.case = FALSE, \dots)
%
%\method{print}{hexmode}(x, \dots)
%}
%\arguments{
%  \item{x}{An object, for the methods inheriting from class \code{"hexmode"}.}
%  \item{width}{\code{NULL} or a positive integer specifying the minimum
%    field width to be used, with padding by leading zeroes.}
%  \item{upper.case}{a logical indicating whether to use upper-case
%    letters or lower-case letters (default).}
%  \item{\dots}{further arguments passed to or from other methods.}
%}
%\details{
%  Class \code{"hexmode"} consists of integer vectors with that class
%  attribute, used merely to ensure that they are printed in hex.
%
%  If \code{width = NULL} (the default), the output is padded with
%  leading zeroes to the smallest width needed for all the non-missing
%  elements.
%
%  \code{as.hexmode} can convert integers (of \link{type} \code{"integer"} or
%  \code{"double"}) and character vectors whose elements contain only
%  \code{0-9}, \code{a-f}, \code{A-F} (or are \code{NA}) to class
%  \code{"hexmode"}.
%
%  There is a \code{\link{!}} method and \code{\link{|}}, \code{\link{&}} and
%  \code{\link{xor}} methods: these recycle their arguments to the
%  length of the longer and then apply the operators bitwise to each
%  element.
%}
%\seealso{
%  \code{\link{octmode}}, \code{\link{sprintf}} for other options in
%  converting integers to hex, \code{\link{strtoi}} to convert hex
%  strings to integers.
%}
%\examples{
%i <- as.hexmode("7fffffff")
%i; class(i)
%identical(as.integer(i), .Machine$integer.max)
%
%hm <- as.hexmode(c(NA, 1)); hm
%as.integer(hm)
%}
%\keyword{utilities}
%\keyword{print}
%
\encoding{UTF8}
