% File src/library/base/man/list.files.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{list.files}
\alias{list.files}
\alias{dir}
\alias{list.dirs}
\title{List the Files in a Directory/Folder}
\usage{
list.files(path = ".", pattern = NULL, all.files = FALSE,
           full.names = FALSE, recursive = FALSE,
           ignore.case = FALSE, include.dirs = FALSE, no.. = FALSE)

       dir(path = ".", pattern = NULL, all.files = FALSE,
           full.names = FALSE, recursive = FALSE,
           ignore.case = FALSE, include.dirs = FALSE, no.. = FALSE)

list.dirs(path = ".", full.names = TRUE, recursive = TRUE)
}
\arguments{
  \item{path}{完全なパス名の文字列ベクトル；
    既定値は作業ディレクトリ \code{\link{getwd}()} に対応する．
    チルド展開が行われる(\code{\link{path.expand}} を見よ)．欠損値は
    無視される．}
  \item{pattern}{オプションの正規表現．正規表現にマッチするファイル名だけが返される．}
  \item{all.files}{論理値．もし \code{FALSE} ならば隠しファイルの名前は
    返され無い．もし \code{TRUE} ならば全てのファイル名が返される．}
  \item{full.names}{論理値．もし \code{TRUE} ならディレクトリパスが
    相対ファイルパスを表すファイル名の先頭に付け加えられる．}
  \item{recursive}{論理値．ディレクトリ内部まで再帰的にリストするか?}
  \item{ignore.case}{論理値．パターンマッチングは大・小文字を区別すべきか?}
  \item{include.dirs}{論理値．再帰的リスティング中でサブディレクトリ名を
    含めるべきか?  (これらは非再帰的なもののなかに常にある)．}
  \item{no..}{論理値．\code{"."} と \code{".."} 双方も
    非再帰的リスティングから除外されるべきか?}
}
\description{
  これらの関数はファイルの名前の文字列ベクトルや名前付きディレクトリ中の
  ディレクトリを作る．
}
\value{
  指定されたディレクトリ内のファイルの名前を含む文字列ベクトル，又は
  ファイルがなければ \code{""}．もしパスが存在しないか読込み不可ならば
  警告無しにスキップされる．

  もし \code{full.names = TRUE} ならばファイルはフルパスに関して
  アルファベット順にソートされている．
  
  \code{list.dirs} は暗黙のうちに \code{all.files = TRUE} を持ち，
  もし \code{recursive = TRUE} ならば回答は \code{path} 自体を含む
  (それが読み込み可能なディレクトリである限り)．
}
\author{Ross Ihaka, Brian Ripley}
\note{
  ファイル名の約束はプラットフォーム依存である．パターンマッチングが大・小文字を
  区別するかどうかは OS がそうするかどうかに依存する．
#ifdef unix

  POSIX ファイルシステムではリストはディレクトリへのシンボリックリンク
  をフォローする．
#endif
#ifdef windows

  \code{path} のパス指定は現在のコードページで表現可能でなければならない．
  そしてそのコードページで表現不可能な \code{path} の下のファイル/ディレクトリ
  は恐らく見つけられない可能性が高い．
#endif
}
\seealso{
  もっと多くのファイルを扱う関数には \code{\link{file.info}}, \code{\link{file.access}}
  and \code{\link{files}} そして対話的な選択には \code{\link{file.choose}}
#ifdef windows
   と \code{\link{choose.files}}
#endif
  ．

  ワイルドカード(システムのファイル命令やシェルが使うような)を正規表現に
  変えるには \code{\link{glob2rx}}．

  ファイルパスに関するワイルドカードの展開には \code{\link{Sys.glob}}．
}
\examples{
list.files(R.home())
## a-l か r で始まるファイルだけ
## a-l はロケール依存であるが，大・小文字の区別の無いマッチング
## は英語のロケールでは曖昧さが無い
dir("../..", pattern = "^[a-lr]", full.names = TRUE, ignore.case = TRUE)

list.dirs(R.home("doc"))
list.dirs(R.home("doc"), full.names = FALSE)
}
\keyword{file}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/list.files.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{list.files}
%\alias{list.files}
%\alias{dir}
%\alias{list.dirs}
%\title{List the Files in a Directory/Folder}
%\usage{
%list.files(path = ".", pattern = NULL, all.files = FALSE,
%           full.names = FALSE, recursive = FALSE,
%           ignore.case = FALSE, include.dirs = FALSE, no.. = FALSE)
%
%       dir(path = ".", pattern = NULL, all.files = FALSE,
%           full.names = FALSE, recursive = FALSE,
%           ignore.case = FALSE, include.dirs = FALSE, no.. = FALSE)
%
%list.dirs(path = ".", full.names = TRUE, recursive = TRUE)
%}
%\arguments{
%  \item{path}{a character vector of full path names; the default
%    corresponds to the working directory, \code{\link{getwd}()}.  Tilde
%    expansion (see \code{\link{path.expand}}) is performed.  Missing
%    values will be ignored.}
%  \item{pattern}{an optional \link{regular expression}.  Only file names
%    which match the regular expression will be returned.}
%  \item{all.files}{a logical value.  If \code{FALSE}, only the
%    names of visible files are returned.  If \code{TRUE},
%    all file names will be returned.}
%  \item{full.names}{a logical value.  If \code{TRUE}, the directory
%    path is prepended to the file names to give a relative file path.
%    If \code{FALSE}, the file names (rather than paths) are returned.}
%  \item{recursive}{logical.  Should the listing recurse into directories?}
%  \item{ignore.case}{logical.  Should pattern-matching be case-insensitive?}
%  \item{include.dirs}{logical.  Should subdirectory names be included in
%    recursive listings?  (They always are in non-recursive ones).}
%  \item{no..}{logical.  Should both \code{"."} and \code{".."} be excluded
%    also from non-recursive listings?}
%}
%\description{
%  These functions produce a character vector of the names of files or
%  directories in the named directory.
%}
%\value{
%  A character vector containing the names of the files in the
%  specified directories, or \code{""} if there were no files.  If a
%  path does not exist or is not a directory or is unreadable it
%  is skipped, with a warning.
%
%  The files are sorted in alphabetical order, on the full path
%  if \code{full.names = TRUE}.
%
%  \code{list.dirs} implicitly has \code{all.files = TRUE}, and if
%  \code{recursive = TRUE}, the answer includes \code{path} itself
%  (provided it is a readable directory).
%}
%\author{Ross Ihaka, Brian Ripley}
%\note{
%  File naming conventions are platform dependent.  The pattern matching
%  works with the case of file names as returned by the OS.
%#ifdef unix
%
%  On a POSIX filesystem recursive listings will follow symbolic links to
%  directories.
%#endif
%#ifdef windows
%
%  \code{path} must specify paths which can be represented in the current
%  codepage, and files/directories below \code{path} whose names cannot
%  be represented in that codepage will most likely not be found.
%#endif
%}
%\seealso{\code{\link{file.info}}, \code{\link{file.access}}
%  and \code{\link{files}} for many more file handling functions and
%  \code{\link{file.choose}}
%#ifdef windows
%  and \code{\link{choose.files}}
%#endif
%  for interactive selection.
%
%  \code{\link{glob2rx}} to convert wildcards (as used by system file
%  commands and shells) to regular expressions.
%
%  \code{\link{Sys.glob}} for wildcard expansion on file paths.
%}
%\examples{
%list.files(R.home())
%## Only files starting with a-l or r
%## Note that a-l is locale-dependent, but using case-insensitive
%## matching makes it unambiguous in English locales
%dir("../..", pattern = "^[a-lr]", full.names = TRUE, ignore.case = TRUE)
%
%list.dirs(R.home("doc"))
%list.dirs(R.home("doc"), full.names = FALSE)
%}
%\keyword{file}
%
\encoding{UTF8}
