% File src/library/base/man/locales.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{locales}
\alias{locales}
\alias{Sys.getlocale}
\alias{Sys.setlocale}
\alias{LC_ALL}
\alias{LC_COLLATE}
\alias{LC_CTYPE}
\alias{LC_MONETARY}
\alias{LC_NUMERIC}
\alias{LC_TIME}

#ifdef unix
\alias{LC_MESSAGES}
\alias{LC_PAPER}
\alias{LC_MEASUREMENT}
#endif

\title{Query or Set Aspects of the Locale}
\description{
  \R プロセスに対するロケールの様相を得る，設定する．
}
\usage{
Sys.getlocale(category = "LC_ALL")
Sys.setlocale(category = "LC_ALL", locale = "")
}
\arguments{
  \item{category}{文字列．以下のカテゴリーは常にサポートされるべきである：
     \code{"LC_ALL"}, \code{"LC_COLLATE"},
    \code{"LC_CTYPE"}, \code{"LC_MONETARY"}, \code{"LC_NUMERIC"} そして
    \code{"LC_TIME"}.  ある種のシステム(Windows でない)はまた
    \code{"LC_MESSAGES"}, \code{"LC_PAPER"} そして \code{"LC_MEASUREMENT"}
    をサポートする．
  }
  \item{locale}{文字列．使用中のシステム上の適正なロケール名．
    通常 \code{""} (既定)はシステムの既定ロケールをピックアップする．}
}
\details{
  ロケールはプログラムの国際化の様々な側面を記述する．
  最初 \R のロケールの殆どの様相は \code{"C"} に設定されている
  (これは C 言語に対する既定で北米の用法を反映している)．
  \R は \code{"LC_CTYPE"} と \code{"LC_COLLATE"} を設定する．
  これは異なった文字セットとその文字セットでのアルファベット比較
  の使用を許し，
  (\code{\link{sort}} の使用を含む)，\code{"LC_MONETARY"}
  (\code{\link{Sys.localeconv}} が使用)，そして \code{"LC_TIME"} は
  \code{\link{as.POSIXlt}} と \code{\link{strptime}} の挙動と
  それらを使う関数(\code{\link{date}} は除く)に影響するかもしれない．

  ここで説明される最初の7つのカテゴリーは POSIX で規定されたものである．
  \code{"LC_MESSAGES"} はメッセージ翻訳をサポートしないシステム上では \code{"C"}
  であり，Windows ではサポートされない．
  サポートされないカテゴリーの使用を試みるのは \code{Sys.setlocale} に対してエラーになる．

  \code{"LC_ALL"} の設定は
  \code{"LC_COLLATE"}, \code{"LC_CTYPE"}, \code{"LC_MONETARY"} そして
  \code{"LC_TIME"} だけを設定することを注意しよう．

  不正なロケールを設定しようとしても無視される． OS に依存して警告が出るかもしれないし
  出ないかもしれない． 

  セッション中に文字集合を変更しようと試みる(もしそれが異なった文字集合を意味するならば
  \code{Sys.setlocale("LC_TYPE", )} で)ことは出来ないかもしれず，
  ある種の混乱を引き起こしやすい．

  環境変数 \env{LANGUAGE} は，ほとんどの \R プラットフォーム上でメッセージ
  翻訳のための言語の選択に於いて \code{"LC_MESSAGES"} に優先する．
  
  ICU が照合に使われているプラットフォームでは，照合用に使われるロケールは
  \code{\link{icuSetCollate}} によって設定できる． Windows を除き，
  初期設定は \code{"LC_COLLATE"} カテゴリーから取られ，
  これが \code{Sys.setlocale} の呼び出しで変更された時はリセットされる．
}
\value{
  長さ1の文字列で使用中のロケールを説明する(\code{Sys.setlocale} による設定後)，
  又はもし現在のロケール設定が不正ならば空の文字列で，
  もしロケール情報が利用できなければ \code{NULL}．

  \code{category = "LC_ALL"} に対しては文字列の詳細はシステム依存である：
  一つのロケール名かもしれないし，\code{"/"} (Solaris, OS X) か
  \code{";"} (Windows, Linux)で区切られたロケール名のセット
  かもしれない．
  可搬性のためにはカテゴリーは個別に問い合わせたほうが良い：
  \code{foo <- Sys.getlocale()} の結果が
  \code{Sys.setlocale("LC_ALL", locale = foo)} 中で
  使えるとは限らない．
}
% assume this just affects strtod/atof, scanf/printf and friends,
% as seems to be the case in glibc.
\section{警告}{
  設定 \code{"LC_NUMERIC"} は \R が異常をもたらす可能性があり警告が出る．
  \R 中の入力変換自体は影響を受けないが，ASCII ファイルやパッケージの
  読み書きや影響を受けるかもしれない．

  Unix 風システムで，グラフィカル又はテキスト出力を作るためそれを
  一時的に設定することは上手く動作するかもしれないが，
  \code{\link{options}(OutDec)} の使用が好ましい．

  国際化されていない Trio ライブラリを使うため，Windows では \R 自体が
  使うほとんどすべての出力ルーチンは
  設定 \code{"LC_NUMERIC"} を無視する．
}

\note{
  \R が稼働中にロケールのカテゴリーの値を変更することは
  OS サービスによって気づかれるべきである．
  そして通常そうであるが，例外も見受けられる(普通照合サービスに於いて)．
}

\seealso{
  \code{category = "LC_TIME"} の使用に対しては \code{\link{strptime}}．
  数値と通貨表示の詳細は \code{\link{Sys.localeconv}}．
  \code{\link{l10n_info}} はロケールとそのエンコーディングに関する
  幾つかの要約を与える．

  ロケールの背景と自分のシステムのロケールの見つけ方に対しては
  マニュアル \sQuote{R Installation and Administration}．
}
\examples{
Sys.getlocale()
Sys.getlocale("LC_TIME")
\dontrun{
Sys.setlocale("LC_TIME", "de")     # Solaris: 詳細は OS 依存
Sys.setlocale("LC_TIME", "de_DE.utf8")   # 現代の Linux 等
Sys.setlocale("LC_TIME", "de_DE.UTF-8")  # 同上
Sys.setlocale("LC_TIME", "de_DE")  # OS X, UTF-8 使用
Sys.setlocale("LC_TIME", "German") # Windows
}
Sys.getlocale("LC_PAPER")          # 設定出来るかもしれないし出来ないかもしれない

\dontrun{
Sys.setlocale("LC_COLLATE", "C")   # 普通ロケール固有のソートをオフにするが
                                   # 全てのプラットフォームに対してではない}
}
\keyword{utilities}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/locales.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{locales}
%\alias{locales}
%\alias{Sys.getlocale}
%\alias{Sys.setlocale}
%\alias{LC_ALL}
%\alias{LC_COLLATE}
%\alias{LC_CTYPE}
%\alias{LC_MONETARY}
%\alias{LC_NUMERIC}
%\alias{LC_TIME}
%
%#ifdef unix
%\alias{LC_MESSAGES}
%\alias{LC_PAPER}
%\alias{LC_MEASUREMENT}
%#endif
%
%\title{Query or Set Aspects of the Locale}
%\description{
%  Get details of or set aspects of the locale for the \R process.
%}
%\usage{
%Sys.getlocale(category = "LC_ALL")
%Sys.setlocale(category = "LC_ALL", locale = "")
%}
%\arguments{
%  \item{category}{character string.  The following categories should
%    always be supported: \code{"LC_ALL"}, \code{"LC_COLLATE"},
%    \code{"LC_CTYPE"}, \code{"LC_MONETARY"}, \code{"LC_NUMERIC"} and
%    \code{"LC_TIME"}.  Some systems (not Windows) will also support
%    \code{"LC_MESSAGES"}, \code{"LC_PAPER"} and \code{"LC_MEASUREMENT"}.
%  }
%  \item{locale}{character string.  A valid locale name on the system in
%    use.  Normally \code{""} (the default) will pick up the default
%    locale for the system.}
%}
%\details{
%  The locale describes aspects of the internationalization of a program.
%  Initially most aspects of the locale of \R are set to \code{"C"} (which
%  is the default for the C language and reflects North-American usage).
%  \R sets \code{"LC_CTYPE"} and \code{"LC_COLLATE"}, which allow the
%  use of a different character set and alphabetic
%  comparisons in that character set (including the use of
%  \code{\link{sort}}), \code{"LC_MONETARY"} (for use by
%  \code{\link{Sys.localeconv}}) and \code{"LC_TIME"} may affect
%  the behaviour of \code{\link{as.POSIXlt}} and \code{\link{strptime}}
%  and functions which use them (but not \code{\link{date}}).
%
%  The first seven categories described here are those specified by
%  POSIX.  \code{"LC_MESSAGES"} will be \code{"C"} on systems that do not
%  support message translation, and is not supported on Windows.  Trying
%  to use an unsupported category is an error for \code{Sys.setlocale}.
%
%  Note that setting category \code{"LC_ALL"} sets only
%  \code{"LC_COLLATE"}, \code{"LC_CTYPE"}, \code{"LC_MONETARY"} and
%  \code{"LC_TIME"}.
%
%  Attempts to set an invalid locale are ignored.  There may or may not
%  be a warning, depending on the OS.
%
%  Attempts to change the character set (by
%  \code{Sys.setlocale("LC_TYPE", )}, if that implies a different
%  character set) during a session may not work and are likely to lead to
%  some confusion.
%
%  Note that the \env{LANGUAGE} environment variable has precedence over
%  \code{"LC_MESSAGES"} in selecting the language for message translation
%  on most \R platforms.
%  
%  On platforms where ICU is used for collation the locale used for
%  collation can be reset by \code{\link{icuSetCollate}}).  Except on
%  Windows, the initial setting is taken from the \code{"LC_COLLATE"}
%  category, and it is reset when this is changed by a call to
%  \code{Sys.setlocale}.
%}
%\value{
%  A character string of length one describing the locale in use (after
%  setting for \code{Sys.setlocale}), or an empty character string if the
%  current locale settings are invalid or \code{NULL} if locale
%  information is unavailable.
%
%  For \code{category = "LC_ALL"} the details of the string are
%  system-specific: it might be a single locale name or a set of locale
%  names separated by \code{"/"} (Solaris, OS X) or \code{";"}
%  (Windows, Linux).  For portability, it is best to query categories
%  individually: it is not necessarily the case that the result of
%  \code{foo <- Sys.getlocale()} can be used in
%  \code{Sys.setlocale("LC_ALL", locale = foo)}.
%}
%% assume this just affects strtod/atof, scanf/printf and friends,
%% as seems to be the case in glibc.
%\section{Warning}{
%  Setting \code{"LC_NUMERIC"} may cause \R to function
%  anomalously, so gives a warning.  Input conversions
%  in \R itself are unaffected, but the reading and writing of ASCII
%  \code{\link{save}} files will be, as may packages.
%
%  Setting it temporarily on a Unix-alike to produce graphical or text
%  output may work well enough, but \code{\link{options}(OutDec)} is
%  often preferable.
%
%  Almost all the output routines used by \R itself under Windows ignore
%  the setting of \code{"LC_NUMERIC"} since they make use of the Trio
%  library which is not internationalized.
%}
%
%\note{
%  Changing the values of locale categories whilst \R is running ought
%  to be noticed by the OS services, and usually is but exceptions have
%  been seen (usually in collation services).
%}
%
%\seealso{
%  \code{\link{strptime}} for uses of \code{category = "LC_TIME"}.
%  \code{\link{Sys.localeconv}} for details of numerical and monetary
%  representations.
%
%  \code{\link{l10n_info}} gives some summary facts about the locale and
%  its encoding.
%
%  The \sQuote{R Installation and Administration} manual for background
%  on locales and how to find out locale names on your system.
%}
%\examples{
%Sys.getlocale()
%Sys.getlocale("LC_TIME")
%\dontrun{
%Sys.setlocale("LC_TIME", "de")     # Solaris: details are OS-dependent
%Sys.setlocale("LC_TIME", "de_DE.utf8")   # Modern Linux etc.
%Sys.setlocale("LC_TIME", "de_DE.UTF-8")  # ditto
%Sys.setlocale("LC_TIME", "de_DE")  # OS X, in UTF-8
%Sys.setlocale("LC_TIME", "German") # Windows
%}
%Sys.getlocale("LC_PAPER")          # may or may not be set
%
%\dontrun{
%Sys.setlocale("LC_COLLATE", "C")   # turn off locale-specific sorting,
%                                   # usually, but not on all platforms}
%}
%\keyword{utilities}
%
\encoding{UTF8}
