% File src/library/base/man/missing.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2009 R Core Team
% Distributed under GPL 2 or later

\name{missing}
\alias{missing}
\title{Does a Formal Argument have a Value?}
\usage{
missing(x)
}
\description{
\code{missing} は値が関数の引数として指定されているかどうかを検査するのに
使うことができる．
}
\arguments{
  \item{x}{形式的引数．}
}
\details{
  \code{missing(x)} は \code{x} が関数に登場してから変更されていない
  場合だけ信頼できる：特に
  それは \code{x <- match.arg(x)} の跡では\emph{常に}偽になる．

  下の例は，プロットされる点の x, y 座標を与えるベクトルの対と，
  それらの添字に対してプロットされる y 値を与える単一のベクトル，
  のどちらででも動作するプロット関数の書き方を示している．

  現在 \code{missing} は引数を定義する関数の直接の本体中でのみ使え，
  入れ子になった関数の本体や局所的な呼び出しの中では使えない．
  これは将来変わるかもしれない．

  これは\sQuote{特殊な}プリミティブ関数である：それはその引数を評価してはならない．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.

  Chambers, J. M. (1998)
  \emph{Programming with Data.  A Guide to the S Language}.
  Springer.
}
\seealso{
  引数表現式については \code{\link{substitute}}；
  データ中の欠損値については \code{\link{NA}}．
}
\examples{
myplot <- function(x, y) {
                if(missing(y)) {
                        y <- x
                        x <- 1:length(y)
                }
                plot(x, y)
        }
}
\keyword{programming}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/missing.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2009 R Core Team
%% Distributed under GPL 2 or later
%
%\name{missing}
%\alias{missing}
%\title{Does a Formal Argument have a Value?}
%\usage{
%missing(x)
%}
%\description{
%\code{missing} can be used to test whether a value was specified
%as an argument to a function.
%}
%\arguments{
%  \item{x}{a formal argument.}
%}
%\details{
%  \code{missing(x)} is only reliable if \code{x} has not been altered
%  since entering the function: in particular it will \emph{always}
%  be false after \code{x <- match.arg(x)}.
%
%  The example shows how a plotting function can be written to work with
%  either a pair of vectors giving x and y coordinates of points to be
%  plotted or a single vector giving y values to be plotted against their
%  indices.
%
%  Currently \code{missing} can only be used in the immediate body of
%  the function that defines the argument, not in the body of a nested
%  function or a \code{local} call.  This may change in the future.
%
%  This is a \sQuote{special} \link{primitive} function: it must not
%  evaluate its argument.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%
%  Chambers, J. M. (1998)
%  \emph{Programming with Data.  A Guide to the S Language}.
%  Springer.
%}
%\seealso{
%  \code{\link{substitute}} for argument expression;
%  \code{\link{NA}} for missing values in data.
%}
%\examples{
%myplot <- function(x, y) {
%                if(missing(y)) {
%                        y <- x
%                        x <- 1:length(y)
%                }
%                plot(x, y)
%        }
%}
%\keyword{programming}
%
\encoding{UTF8}
