% File src/library/base/man/octmode.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2011 R Core Team
% Distributed under GPL 2 or later

\name{octmode}
\alias{as.octmode}
\alias{format.octmode}
\alias{print.octmode}
\alias{as.character.octmode}
\alias{[.octmode}
\alias{!.octmode}
\alias{|.octmode}
\alias{&.octmode}
\alias{xor.octmode}
\alias{octmode}
\title{Display Numbers in Octal}
\description{
  整数を8進法書式に変換したりプリントしたりする．
  必要なら先頭にゼロを補い，最大なものを表示するのに必要なだけの
  桁を持つ．
}
\usage{
as.octmode(x)

\method{as.character}{octmode}(x, \dots)

\method{format}{octmode}(x, width = NULL, \dots)

\method{print}{octmode}(x, \dots)
}
\arguments{
  \item{x}{オブジェクト，メソッドに対してはクラス \code{"octmode"}
  を継承する．}
  \item{width}{\code{NULL} か使われる最小の欄幅を指定する正整数で，
    先頭がゼロで埋められる．}
  \item{\dots}{他のメソッドに・から渡される追加引数．}
}
\details{
  クラス \code{"octmode"} はその属性を持つ整数ベクトルからなり，
  それらが8進法表記でプリントされることを保証するためだけに使われる．
  特に \code{755} のような Unix 風のファイルのパーミッションが
  例である．添字による部分抽出操作(\code{\link{[}})も使える．

  もし \code{width = NULL} (既定)ならば，出力は全ての非欠損要素が
  必要な最小の幅になるように先頭がゼロで埋められる．

  \code{as.octmode} は整数(型 \code{"integer"} 又は \code{"double"})や，
  その要素が数字 \code{0-7} (又は \code{NA})だけを含む文字列ベクトル
  をクラス \code{"octmode"} に変換できる．

  メソッド \code{\link{!}}，\code{\link{|}}, \code{\link{&}} そして
  \code{\link{xor}} メソッドがある：これらはその引数を長い方の長さまで
  リサイクル使用し，そしてそれから各要素にビット単位で操作を適用する．
}
\seealso{
  これらは \code{\link{file.info}} に対する補助関数である．

  整数を8進法に変換する際の他のオプションに付いては
  \code{\link{hexmode}} と \code{\link{sprintf}}．
  8進法文字列を整数に変換するには \code{\link{strtoi}}．
  strings to integers.
}
\examples{
(on <- as.octmode(c(16, 32, 127:129))) # "020" "040" "177" "200" "201"
unclass(on[3:4]) # 添字による部分抽出操作

## ファイルのモードを操作する
fmode <- as.octmode("170")
(fmode | "644") & "755"
\donttest{
umask <- Sys.umask(NA) # プラットフォーム依存
c(fmode, "666", "755") & !umask
}}
\keyword{utilities}
\keyword{print}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/octmode.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2011 R Core Team
%% Distributed under GPL 2 or later
%
%\name{octmode}
%\alias{as.octmode}
%\alias{format.octmode}
%\alias{print.octmode}
%\alias{as.character.octmode}
%\alias{[.octmode}
%\alias{!.octmode}
%\alias{|.octmode}
%\alias{&.octmode}
%\alias{xor.octmode}
%\alias{octmode}
%\title{Display Numbers in Octal}
%\description{
%  Convert or print integers in octal format, with as many digits as are
%  needed to display the largest, using leading zeroes as necessary.
%}
%\usage{
%as.octmode(x)
%
%\method{as.character}{octmode}(x, \dots)
%
%\method{format}{octmode}(x, width = NULL, \dots)
%
%\method{print}{octmode}(x, \dots)
%}
%\arguments{
%  \item{x}{An object, for the methods inheriting from class \code{"octmode"}.}
%  \item{width}{\code{NULL} or a positive integer specifying the minimum
%    field width to be used, with padding by leading zeroes.}
%  \item{\dots}{further arguments passed to or from other methods.}
%}
%\details{
%  Class \code{"octmode"} consists of integer vectors with that class
%  attribute, used merely to ensure that they are printed in octal
%  notation, specifically for Unix-like file permissions such as
%  \code{755}.  Subsetting (\code{\link{[}}) works too.
%
%  If \code{width = NULL} (the default), the output is padded with
%  leading zeroes to the smallest width needed for all the non-missing
%  elements.
%
%  \code{as.octmode} can convert integers (of \link{type} \code{"integer"} or
%  \code{"double"}) and character vectors whose elements contain only
%  digits \code{0-7} (or are \code{NA}) to class \code{"octmode"}.
%
%  There is a \code{\link{!}} method and \code{\link{|}}, \code{\link{&}} and
%  \code{\link{xor}} methods: these recycle their arguments to the
%  length of the longer and then apply the operators bitwise to each
%  element.
%}
%\seealso{
%  These are auxiliary functions for \code{\link{file.info}}.
%
%  \code{\link{hexmode}}, \code{\link{sprintf}} for other options in
%  converting integers to octal, \code{\link{strtoi}} to convert octal
%  strings to integers.
%}
%\examples{
%(on <- as.octmode(c(16, 32, 127:129))) # "020" "040" "177" "200" "201"
%unclass(on[3:4]) # subsetting
%
%## manipulate file modes
%fmode <- as.octmode("170")
%(fmode | "644") & "755"
%\donttest{
%umask <- Sys.umask(NA) # depends on platform
%c(fmode, "666", "755") & !umask
%}}
%\keyword{utilities}
%\keyword{print}
%
\encoding{UTF8}
