% File src/library/base/man/on.exit.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{on.exit}
\alias{on.exit}
\title{Function Exit Code}
\description{
  \code{on.exit} はその引数で与えられた表現式を，現在の関数が終了した時
  (自然にもしくはエラーの結果として)に実行されるように記録する．
  これはグラフィックスのパラメータの再設定や他のクリーン化作業を
  実行するのに有用である．

  表現式が与えられない，つまり呼び出しが \code{on.exit()}，と
  現在の \code{on.exit} コードは取り除かれる．
}
\usage{
on.exit(expr = NULL, add = FALSE)
}
\arguments{
  \item{expr}{評価される表現式．}
  \item{add}{もし TRUE ならば任意の先に設定された表現式の後に
  \code{expr} を実行用に付け加える；さもなければ(既定)
    \code{expr} は任意の先に設定された表現式を上書きする．}
}
\details{
  \code{on.exit} に渡された \code{expr} 引数は評価されずに保存される．
  もしそれがその後同じ関数中の  \code{on.exit} 呼び出しで除去されたり
  置き換えられたりしなければ，関数の評価フレーム中でそれが終了した時
  (標準エラー処理を含め)評価される．このように表現式中の任意の関数や変数
  は終了時に関数とその環境中で探される：
  \code{expr} 中の現在の値を捉えるには \code{\link{substitute}} や
  類似物を使う．

  これは\sQuote{特殊}プリミティブ関数である：これは引数 \code{add} だけを
  評価する．
}
\value{
  不可視の \code{NULL}．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\seealso{
  \code{sys.on.exit()} がその中で評価される関数中で
  \code{on.exit()} で使用するため保管された表現式を返す
  \code{\link{sys.on.exit}}．
}
\examples{
require(graphics)

opar <- par(mai = c(1,1,1,1))
on.exit(par(opar))
\dontshow{par(opar)}
}
\keyword{programming}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/on.exit.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{on.exit}
%\alias{on.exit}
%\title{Function Exit Code}
%\description{
%  \code{on.exit} records the expression given as its argument as needing
%  to be executed when the current function exits (either naturally or as
%  the result of an error).  This is useful for resetting graphical
%  parameters or performing other cleanup actions.
%
%  If no expression is provided, i.e., the call is \code{on.exit()}, then
%  the current \code{on.exit} code is removed.
%}
%\usage{
%on.exit(expr = NULL, add = FALSE)
%}
%\arguments{
%  \item{expr}{an expression to be executed.}
%  \item{add}{if TRUE, add \code{expr} to be executed after any previously
%    set expressions; otherwise (the default) \code{expr} will overwrite
%    any previously set expressions.}
%}
%\details{
%  The \code{expr} argument passed to \code{on.exit} is recorded without
%  evaluation.  If it is not subsequently removed/replaced by another
%  \code{on.exit} call in the same function, it is evaluated in the
%  evaluation frame of the function when it exits (including during
%  standard error handling).  Thus any functions or variables in the
%  expression will be looked for in the function and its environment at
%  the time of exit: to capture the current value in \code{expr} use
%  \code{\link{substitute}} or similar.
%
%  This is a \sQuote{special} \link{primitive} function: it only
%  evaluates the argument \code{add}.
%}
%\value{
%  Invisible \code{NULL}.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{sys.on.exit}} which returns the expression stored for use
%  by \code{on.exit()} in the function in which \code{sys.on.exit()} is
%  evaluated.
%}
%\examples{
%require(graphics)
%
%opar <- par(mai = c(1,1,1,1))
%on.exit(par(opar))
%\dontshow{par(opar)}
%}
%\keyword{programming}
%
\encoding{UTF8}
