% File src/library/base/man/pretty.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{pretty}
\title{Pretty Breakpoints}
\usage{
pretty(x, \dots)

\method{pretty}{default}(x, n = 5, min.n = n \%/\% 3,  shrink.sml = 0.75,
       high.u.bias = 1.5, u5.bias = .5 + 1.5*high.u.bias,
       eps.correct = 0, \dots)
}
\alias{pretty}
\alias{pretty.default}
\arguments{
  \item{x}{\code{\link{as.numeric}} で数値に変換可能なオブジェクト．}
  \item{n}{\emph{希望の}区間数を与える整数.
    整数でない値は丸められる．}
  \item{min.n}{区間の\emph{最少}数を与える非負整数．
  もし \code{min.n == 0} なら \code{pretty(.)} は一つの値を返すかもしれない．}
  \item{shrink.sml}{正値で，\code{range(x)} が非常に小さい
    (普通ゼロ)の時既定のスケールがその分縮小される．}
  \item{high.u.bias}{非負数値で通常 \eqn{> 1}．
    区間単位は 10 の巾乗である \code{b} の \{1,2,5,10\} 倍に定められる．
    大きな \code{high.u.bias} の値はより大きなユニットを優先する．}
  \item{u5.bias}{因子 5 を 2 より優先する非負の乗数．\cr
    既定と\sQuote{最適}：
    \code{u5.bias = .5 + 1.5*high.u.bias}．}
  \item{eps.correct}{整数コードで \{0,1,2\} のどれか．もし 0 で
    無ければ，結果の境界が \code{range(x)} の外部になるように境界で
    \emph{イプシロン修正}が行われる；
    \emph{小さい}ケースでは修正は \code{eps.correct >= 2} の
    時だけ行われる．}
  \item{\dots}{メソッドへの追加引数．}
}
\description{
  \code{x} 中の値の範囲をカバーする
  約 \code{n+1} 個の等間隔の\sQuote{丸められた}値を計算する．
  値はそれらが 10 の巾乗の 1, 2 又は 5 倍になるように選ばれる．
}
\details{
  \code{pretty} は \code{x} 中の非有限な値を無視する．

  \code{d <- max(x) - min(x)} \eqn{\ge 0} とする．
  もし \code{d} が 0 (か非常に近い)でなければ，\code{c <- d/n} とする，
  さもなければ約 \code{c <- max(abs(range(x)))*shrink.sml / min.n}．
  すると 10 の\emph{巾乗}の \code{b} は
  \eqn{10^{\lfloor{\log_{10}(c)}\rfloor}}{10^(floor(log10(c)))} となり
  \eqn{b \le c < 10b} となる．

  そして基本\emph{ユニット} \eqn{u} を
  \eqn{c/b \in [1,10)}{c/b in [1,10)} に応じて
  \eqn{\{1,2,5,10\}}{{1,2,5,10}} のどれかの \code{b} 倍にする．
  そして二つの\sQuote{\emph{バイアス}}係数は
  \eqn{h =}\code{ high.u.bias} と \eqn{f =}\code{ u5.bias} にする．

  \dots\dots\dots
}
\seealso{
  特に対数スケールの場合のプロットの見栄えの良い軸チック位置の
  計算には \code{\link{axTicks}}．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\examples{
pretty(1:15)          # 0  2  4  6  8 10 12 14 16
pretty(1:15, h = 2)   # 0  5 10 15
pretty(1:15, n = 4)   # 0  5 10 15
pretty(1:15 * 2)      # 0  5 10 15 20 25 30
pretty(1:20)          # 0  5 10 15 20
pretty(1:20, n = 2)   # 0 10 20
pretty(1:20, n = 10)  # 0  2  4 ... 20

for(k in 5:11) {
  cat("k=", k, ": "); print(diff(range(pretty(100 + c(0, pi*10^-k)))))}

##-- min(x) == max(x) の時にはもっと異様：
pretty(pi)

add.names <- function(v) { names(v) <- paste(v); v}
utils::str(lapply(add.names(-10:20), pretty))
utils::str(lapply(add.names(0:20),   pretty, min.n = 0))
sapply(    add.names(0:20),   pretty, min.n = 4)

pretty(1.234e100)
pretty(1001.1001)
pretty(1001.1001, shrink = 0.2)
for(k in -7:3)
  cat("shrink=", formatC(2^k, width = 9),":",
      formatC(pretty(1001.1001, shrink.sml = 2^k), width = 6),"\n")
}
\keyword{dplot}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/pretty.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{pretty}
%\title{Pretty Breakpoints}
%\usage{
%pretty(x, \dots)
%
%\method{pretty}{default}(x, n = 5, min.n = n \%/\% 3,  shrink.sml = 0.75,
%       high.u.bias = 1.5, u5.bias = .5 + 1.5*high.u.bias,
%       eps.correct = 0, \dots)
%}
%\alias{pretty}
%\alias{pretty.default}
%\arguments{
%  \item{x}{an object coercible to numeric by \code{\link{as.numeric}}.}
%  \item{n}{integer giving the \emph{desired} number of
%    intervals.  Non-integer values are rounded down.}
%  \item{min.n}{nonnegative integer giving the \emph{minimal} number of
%    intervals.  If \code{min.n == 0}, \code{pretty(.)} may return a
%    single value.}
%  \item{shrink.sml}{positive numeric
%    by a which a default scale is shrunk in the case when
%    \code{range(x)} is very small (usually 0).}
%  \item{high.u.bias}{non-negative numeric, typically \eqn{> 1}.
%    The interval unit is determined as \{1,2,5,10\} times \code{b}, a
%    power of 10.  Larger \code{high.u.bias} values favor larger units.}
%  \item{u5.bias}{non-negative numeric
%    multiplier favoring factor 5 over 2.  Default and \sQuote{optimal}:
%    \code{u5.bias = .5 + 1.5*high.u.bias}.}
%  \item{eps.correct}{integer code, one of \{0,1,2\}. If non-0, an
%    \emph{epsilon correction} is made at the boundaries such that
%    the result boundaries will be outside \code{range(x)}; in the
%    \emph{small} case, the correction is only done if \code{eps.correct
%       >= 2}.}
%  \item{\dots}{further arguments for methods.}
%}
%\description{
%  Compute a  sequence of about \code{n+1} equally spaced \sQuote{round}
%  values which cover the range of the values in \code{x}.
%  The values are chosen so that they are 1, 2 or 5 times a power of 10.
%}
%\details{
%  \code{pretty} ignores non-finite values in \code{x}.
%
%  Let \code{d <- max(x) - min(x)} \eqn{\ge 0}.
%  If \code{d} is not (very close) to 0, we let \code{c <- d/n},
%  otherwise more or less \code{c <- max(abs(range(x)))*shrink.sml / min.n}.
%  Then, the \emph{10 base} \code{b} is
%  \eqn{10^{\lfloor{\log_{10}(c)}\rfloor}}{10^(floor(log10(c)))} such
%  that \eqn{b \le c < 10b}.
%
%  Now determine the basic \emph{unit} \eqn{u} as one of
%  \eqn{\{1,2,5,10\} b}{{1,2,5,10} b}, depending on
%  \eqn{c/b \in [1,10)}{c/b in [1,10}
%  and the two \sQuote{\emph{bias}} coefficients, \eqn{h
%  =}\code{high.u.bias} and \eqn{f =}\code{u5.bias}.
%
%  \dots\dots\dots
%}
%\seealso{
%  \code{\link{axTicks}} for the computation of pretty axis tick
%  locations in plots, particularly on the log scale.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\examples{
%pretty(1:15)          # 0  2  4  6  8 10 12 14 16
%pretty(1:15, h = 2)   # 0  5 10 15
%pretty(1:15, n = 4)   # 0  5 10 15
%pretty(1:15 * 2)      # 0  5 10 15 20 25 30
%pretty(1:20)          # 0  5 10 15 20
%pretty(1:20, n = 2)   # 0 10 20
%pretty(1:20, n = 10)  # 0  2  4 ... 20
%
%for(k in 5:11) {
%  cat("k=", k, ": "); print(diff(range(pretty(100 + c(0, pi*10^-k)))))}
%
%##-- more bizarre, when  min(x) == max(x):
%pretty(pi)
%
%add.names <- function(v) { names(v) <- paste(v); v}
%utils::str(lapply(add.names(-10:20), pretty))
%utils::str(lapply(add.names(0:20),   pretty, min.n = 0))
%sapply(    add.names(0:20),   pretty, min.n = 4)
%
%pretty(1.234e100)
%pretty(1001.1001)
%pretty(1001.1001, shrink = 0.2)
%for(k in -7:3)
%  cat("shrink=", formatC(2^k, width = 9),":",
%      formatC(pretty(1001.1001, shrink.sml = 2^k), width = 6),"\n")
%}
%\keyword{dplot}
%
\encoding{UTF8}
