% File src/library/base/man/print.default.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{print.default}
\alias{print.default}
\description{
  \code{print.default} はその引数をプリントする
  総称的な関数 \code{\link{print}} の既定メソッドである．
}
\title{Default Printing}
\usage{
\method{print}{default}(x, digits = NULL, quote = TRUE,
      na.print = NULL, print.gap = NULL, right = FALSE,
      max = NULL, useSource = TRUE, \dots)
}
\arguments{
  \item{x}{プリントされるオブジェクト．}
  \item{digits}{\code{digits} に対する null でない値で，
    値をプリントする最少の有効桁数を指定する．既定の
    \code{NULL} は \code{\link{getOption}("digits")} を使う．
    (複素数に対する解釈は \code{\link{signif}} を見よ．)
    非整数値は切り下げられ，1 以上で 22 以下の値だけが受け入れられる．
  }
  \item{quote}{論理値，文字列
    (\code{\link{character}})を引用符付きでプリントするかどうかを指示する．}
  \item{na.print}{プリント出力中で \code{\link{NA}} 値を指示するのに
    使われる文字列，又は \code{NULL} (\sQuote{詳細} を見よ)．}
  \item{print.gap}{1024 未満の非負整数
    又は \code{NULL} (1 を意味する)で，プリントされるベクトル，行列そして
    配列中で隣り合う列間に置かれるスペース．}
  \item{right}{論理値，文字列を右揃えにするかどうかを指示する．
    既定は左揃え．}
  \item{max}{\code{max} に対する null でない値で，プリントされる
    項目の最大数の近似値．既定値 \code{NULL} は
    \code{\link{getOption}("max.print")} を使う；
    より詳細はそのヘルプを見よ．}
  \item{useSource}{論理値で，言語オブジェクトを逆構文解析する代わりに
    ソース参照やコピーを使うことを指示する．
    既定では利用可能ならオリジナルのソースを使う．}
  \item{\dots}{他のメソッドへ・から渡される追加引数．
    この関数では無視される．}
}
\details{
  \code{NA} のプリントに対する既定値は
  これが \code{NA} \emph{そして} \code{quote = FALSE} で無い限り
  \code{NA} (引用符なしで)でプリントされる．それ以外は
  \samp{<NA>} とプリントされる．

  ベクトルを通じて同じ小数点以下の桁数が使われる．
  これは \code{digits} が使われる最少の有効桁数を指定し，
  少なくともひとつの項目がその最少桁数で表現されることを意味する．
  しかしながら，もし全ての表現要素がその結果末尾にゼロを持つようになれば，
  小数点以下の桁が少なくともひとつの要素がゼロでない末位を持つように
  少なくされる．小数点以下の桁数は少なくとも一つの要素が
  それを持つ時だけ導入される．

  属性はそれらのクラスを尊重してプリントされる．
  \code{digits} の値を \code{print.default} に利用するが，
  他のメソッドの既定値(呼びだされたメソッドに対して)を利用する．

  オプション \code{width} はベクトル，行列そして配列のプリントを制御し，
  オプション \code{deparse.cutoff} は呼び出しや公式のような
  言語オブジェクトのプリントを制御する．

  \pkg{methods} パッケージが付加されると，\code{print} は
  形式的クラスを持つ \R オブジェクト
  に対して，オプション引数無しで呼びだされた時 \code{\link{show}} を
  使う．
}
\section{桁数の多い数}{
  現在 \code{digits >= 16} である \code{digits} の大きな数については，
  有効桁数の計算はプラットフォームの内部(C ライブラリ) \samp{sprintf()} 機能
  に依存することを注意しよう．
}
\section{1バイトロケール}{
  出力の間にプリント不可能な文字が現れるとそれは ANSI のエスケープ
  列の一つ(\samp{\\a}, \samp{\\b}, \samp{\\f}, \samp{\\n}, \samp{\\r},
  \samp{\\t}, \samp{\\v}, \samp{\\\\} そして \samp{\\0}: \link{Quotes} を
  見よ)として，それが失敗すると 3 桁の 8 進法コードで表現される：
  例えば C ロケール中の UK のポンド通貨符号は
  (もし正しく実装されていると) \samp{\\243} のようにプリントされる．
  どの文字がプリントできないかはロケールに依存する．
  (Windows のあるバージョンはこれを誤って受け取るので，上位ビットを持つ
  全てのバイトは 1 バイトロケールの Windows ではプリント可能と
  見做される．)
}

#ifdef unix
\section{Unicode と他の多バイトロケール}{
  全てのロケールで，ASCII 範囲(\samp{0x00} から \samp{0x7f})中の文字は
  もしプリント可能ならそのままで，
  さもなければ 1バイトロケールに対して説明されたように ANSI エスケープ列
  か3桁の8進法数としてプリントされる．

  多バイトのプリント不可能な文字は
  \samp{\\uxxxx} (8進法)や \samp{\\Uxxxxxxxx} (16進法)のような
  エスケープ列としてプリントされる．
  これは文字の幅広文字表現の内部コードである．
  もしこれが Unicode code point として知られていなければ警告が出る．
  既知の唯一の例外は商業 Unix でのある Japanese ISO 2022 ロケールである．
  これはバイトの連結を用いる：
  \R は恐らくそうしたシステムではコンパイルできないであろう．
% https://www.cl.cam.ac.uk/~mgk25/ucs/iso2022-wc.html

  文字列ベクトル中に現在のロケールで不正な文字をもつ文字列があることは
  ありうる．正しい文字の一部ではないバイトが現れるとそれは \samp{\\xab} の
  形の 16 進数法でプリントされ，これが正しい文字が現れるまで続けられる．
  (UTF-8 ではこれは僅かなエラーから素早く回復される．)
}
#endif

#ifdef windows
\section{多バイトロケール}{
  全てのロケールで，ASCII 範囲(\samp{0x00} から \samp{0x7f})中の文字は
  もしプリント可能ならそのままで，
  さもなければ 1バイトロケールに対して説明されたように ANSI エスケープ列
  か3桁の8進法数としてプリントされる．

  多バイトのプリント不可能な文字は
  \samp{\\uxxxx} (8進法)のようなエスケープ列としてプリントされる．
  これは文字の Unicode point である．

  文字列ベクトル中に現在のロケールで不正な文字をもつ文字列があることは
  ありうる．正しい文字の一部ではないバイトが現れるとそれは \samp{\\xab} の
  形の 16 進数法でプリントされ，
  これが正しい文字が現れるまで続けられる．
}
#endif

\seealso{
  総称的な \code{\link{print}} と \code{\link{options}}．
  \code{"\link{noquote}"} クラスとプリントメソッド．

  \code{\link{encodeString}} は文字列をプリント用にエンコードする．
}
\examples{
pi
print(pi, digits = 16)
LETTERS[1:16]
print(LETTERS, quote = FALSE)

M <- cbind(I = 1, matrix(1:10000, ncol = 10,
                         dimnames = list(NULL, LETTERS[1:10])))
utils::head(M)        # より意味がある
print(M, max = 1000)  # 90 列をプリントし，除外した 910 列についてメッセージ
}
\keyword{print}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/print.default.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{print.default}
%\alias{print.default}
%\description{
%  \code{print.default} is the \emph{default} method of the generic
%  \code{\link{print}} function which prints its argument.
%}
%\title{Default Printing}
%\usage{
%\method{print}{default}(x, digits = NULL, quote = TRUE,
%      na.print = NULL, print.gap = NULL, right = FALSE,
%      max = NULL, useSource = TRUE, \dots)
%}
%\arguments{
%  \item{x}{the object to be printed.}
%  \item{digits}{a non-null value for \code{digits} specifies the minimum
%    number of significant digits to be printed in values.  The default,
%    \code{NULL}, uses \code{\link{getOption}("digits")}.  (For the
%    interpretation for complex numbers see \code{\link{signif}}.)
%    Non-integer values will be rounded down, and only values
%    greater than or equal to 1 and no greater than 22 are accepted.
%  }
%  \item{quote}{logical, indicating whether or not strings
%    (\code{\link{character}}s) should be printed with surrounding quotes.}
%  \item{na.print}{a character string which is used to indicate
%    \code{\link{NA}} values in printed output, or \code{NULL}
%    (see \sQuote{Details}).}
%  \item{print.gap}{a non-negative integer \eqn{\le 1024},
%    or \code{NULL} (meaning 1), giving the spacing between adjacent
%    columns in printed vectors, matrices and arrays.}
%  \item{right}{logical, indicating whether or not strings should be
%    right aligned.  The default is left alignment.}
%  \item{max}{a non-null value for \code{max} specifies the approximate
%    maximum number of entries to be printed.  The default, \code{NULL},
%    uses \code{\link{getOption}("max.print")}; see that help page for more
%    details.}
%  \item{useSource}{logical, indicating whether to use source
%    references or copies rather than deparsing \link{language objects}.
%    The default is to use the original source if it is available.}
%  \item{\dots}{further arguments to be passed to or from other
%    methods.  They are ignored in this function.}
%}
%\details{
%  The default for printing \code{NA}s is to print \code{NA} (without
%  quotes) unless this is a character \code{NA} \emph{and} \code{quote =
%    FALSE}, when \samp{<NA>} is printed.
%
%  The same number of decimal places is used throughout a vector.  This
%  means that \code{digits} specifies the minimum number of significant
%  digits to be used, and that at least one entry will be encoded with
%  that minimum number.  However, if all the encoded elements then have
%  trailing zeroes, the number of decimal places is reduced until at
%  least one element has a non-zero final digit.  Decimal points are only
%  included if at least one decimal place is selected.
%
%  Attributes are printed respecting their class(es), using the values of
%  \code{digits} to \code{print.default}, but using the default values
%  (for the methods called) of the other arguments.
%
%  Option \code{width} controls the printing of vectors, matrices and
%  arrays, and option \code{deparse.cutoff} controls the printing of
%  \link{language objects} such as calls and formulae.
%
%  When the \pkg{methods} package is attached, \code{print} will call
%  \code{\link{show}} for \R objects with formal classes if called
%  with no optional arguments.
%}
%\section{Large number of digits}{
%  Note that for large values of \code{digits}, currently for
%  \code{digits >= 16}, the calculation of the number of significant
%  digits will depend on the platform's internal (C library)
%  implementation of \samp{sprintf()} functionality.
%}
%\section{Single-byte locales}{
%  If a non-printable character is encountered during output, it is
%  represented as one of the ANSI escape sequences (\samp{\\a}, \samp{\\b},
%  \samp{\\f}, \samp{\\n}, \samp{\\r}, \samp{\\t}, \samp{\\v}, \samp{\\\\} and
%  \samp{\\0}: see \link{Quotes}), or failing that as a 3-digit octal
%  code: for example the UK currency pound sign in the C locale (if
%  implemented correctly) is printed as \samp{\\243}.  Which characters
%  are non-printable depends on the locale.
%  (Because some versions of Windows get this wrong, all bytes with the
%  upper bit set are regarded as printable on Windows in a single-byte
%  locale.)
%}
%
%#ifdef unix
%\section{Unicode and other multi-byte locales}{
%  In all locales, the characters in the ASCII range (\samp{0x00} to
%  \samp{0x7f}) are printed in the same way, as-is if printable, otherwise
%  via ANSI escape sequences or 3-digit octal escapes as described for
%  single-byte locales.
%
%  Multi-byte non-printing characters are printed as an escape sequence
%  of the form \samp{\\uxxxx} or \samp{\\Uxxxxxxxx} (in hexadecimal).
%  This is the internal code for the wide-character representation of the
%  character.  If this is not known to be Unicode code points, a warning is
%  issued.  The only known exceptions are certain Japanese ISO 2022
%  locales on commercial Unixes, which use a concatenation of the bytes:
%  it is unlikely that \R compiles on such a system.
%% https://www.cl.cam.ac.uk/~mgk25/ucs/iso2022-wc.html
%
%  It is possible to have a character string in a character vector that
%  is not valid in the current locale.  If a byte is encountered that is
%  not part of a valid character it is printed in hex in the form
%  \samp{\\xab} and this is repeated until the start of a valid character.
%  (This will rapidly recover from minor errors in UTF-8.)
%}
%#endif
%
%#ifdef windows
%\section{Multi-byte locales}{
%  In all locales, the characters in the ASCII range (\samp{0x00} to
%  \samp{0x7f}) are printed in the same way, as-is if printable, otherwise
%  via ANSI escape sequences or 3-digit octal escapes as described for
%  single-byte locales.
%
%  Multi-byte non-printing characters are printed as an escape sequence
%  of the form \samp{\\uxxxx} (in hexadecimal). This is the Unicode code
%  point of the character.
%
%  It is possible to have a character string in a character vector that
%  is not valid in the current locale.  If a byte is encountered that is
%  not part of a valid character it is printed in hex in the form
%  \samp{\\xab} and this is repeated until the start of a valid character.
%}
%#endif
%
%\seealso{
%  The generic \code{\link{print}}, \code{\link{options}}.
%  The \code{"\link{noquote}"} class and print method.
%
%  \code{\link{encodeString}}, which encodes a character vector the way
%  it would be printed.
%}
%\examples{
%pi
%print(pi, digits = 16)
%LETTERS[1:16]
%print(LETTERS, quote = FALSE)
%
%M <- cbind(I = 1, matrix(1:10000, ncol = 10,
%                         dimnames = list(NULL, LETTERS[1:10])))
%utils::head(M)        # makes more sense than
%print(M, max = 1000)  # prints 90 rows and a message about omitting 910
%}
%\keyword{print}
%
\encoding{UTF8}
