% File src/library/base/man/prod.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{prod}
\title{Product of Vector Elements}
\description{
  \code{prod} はその引数中にある全ての値の積を返す．
}
\usage{
prod(\dots, na.rm = FALSE)
}
\alias{prod}
\arguments{
  \item{\dots}{数値，複素数値又は論理値ベクトル．}
  \item{na.rm}{論理値．欠損値を取り除くか?}
}
\details{
  もし \code{na.rm} が \code{FALSE} ならその任意の引数中の \code{NA}
  値は返り値を \code{NA} にする．さもなければ \code{NA} 値は無視される．

  これは総称的な関数である：それに対するメソッドを直接に，または
  \code{\link[=S3groupGeneric]{Summary}} グループ総称的に定義できる．
  これが正しく動作するためには，引数 \code{\dots} は名前無しで，
  選択適用はその最初の引数についてである必要がある．

  真の論理値は 1，偽値は 0 と見做される．
  歴史的な理由から \code{NULL} が受け入れられ
  \code{numeric(0)} であるかのように扱われる．
}
\value{
  積である長さ1の数値(型 \code{"double"})か複素数値のベクトル． 
  \strong{注意：} 空集合の積は定義から1である．
}
\section{S4 methods}{
  これは S4 \code{\link[=S4groupGeneric]{Summary}} グループ総称的関数である．
  それに対するメソッドはシグネチャ \code{x, \dots, na.rm} を使わなければならない．.
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\seealso{
  \code{\link{sum}},
  \code{\link{cumprod}}, \code{\link{cumsum}}.

  プロットの注釈中での \code{prod} の利用については \sQuote{\link{plotmath}}．
}
\examples{
print(prod(1:7)) == print(gamma(8))
}
\keyword{arith}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/prod.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{prod}
%\title{Product of Vector Elements}
%\description{
%  \code{prod} returns the product of all the values
%  present in its arguments.
%}
%\usage{
%prod(\dots, na.rm = FALSE)
%}
%\alias{prod}
%\arguments{
%  \item{\dots}{numeric or complex or logical vectors.}
%  \item{na.rm}{logical.  Should missing values be removed?}
%}
%\details{
%  If \code{na.rm} is \code{FALSE} an \code{NA}
%  value in any of the arguments will cause
%  a value of \code{NA} to be returned, otherwise
%  \code{NA} values are ignored.
%
%  This is a generic function: methods can be defined for it
%  directly or via the \code{\link[=S3groupGeneric]{Summary}} group generic.
%  For this to work properly, the arguments \code{\dots} should be
%  unnamed, and dispatch is on the first argument.
%
%  Logical true values are regarded as one, false values as zero.
%  For historical reasons, \code{NULL} is accepted and treated as if it
%  were \code{numeric(0)}.
%}
%\value{
%  The product, a numeric (of type \code{"double"}) or complex vector of length one.
%  \strong{NB:} the product of an empty set is one, by definition.
%}
%\section{S4 methods}{
%  This is part of the S4 \code{\link[=S4groupGeneric]{Summary}}
%  group generic.  Methods for it must use the signature
%  \code{x, \dots, na.rm}.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{sum}},
%  \code{\link{cumprod}}, \code{\link{cumsum}}.
%
%  \sQuote{\link{plotmath}} for the use of \code{prod} in plot annotation.
%}
%\examples{
%print(prod(1:7)) == print(gamma(8))
%}
%\keyword{arith}
%
\encoding{UTF8}
