% File src/library/base/man/source.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2012 R Core Team
% Distributed under GPL 2 or later

\name{source}
\title{Read R Code from a File or a Connection}
\description{
  \code{source} は \R に名前付きファイルや URL や コネクションから
  その入力を受け入れるようにする．入力は読み込まれ，そしてそのファイルから
  ファイルが最後に到達するまで \code{\link{parse}} される．
  それから構文解析された表現式が選択された環境中で逐次的に評価される．
}
\usage{
source(file, local = FALSE, echo = verbose, print.eval = echo,
       verbose = getOption("verbose"),
       prompt.echo = getOption("prompt"),
       max.deparse.length = 150, chdir = FALSE,
       encoding = getOption("encoding"),
       continue.echo = getOption("continue"),
       skip.echo = 0, keep.source = getOption("keep.source"))
}
\alias{source}
\arguments{
  \item{file}{コネクションか，そこから読み取るファイルや URL のパス名を
    与える文字列．\code{""} はコネクション \code{\link{stdin}()} を指示する．}
  \item{local}{\code{TRUE}, \code{FALSE} 又は環境で，
    構文解析された表現式を評価するかを決める．\code{FALSE} (既定)は
    ユーザの作業空間に，\code{TRUE} はそこから \code{source} が
    呼びだされた環境に対応する．}
  \item{echo}{論理値；もし \code{TRUE} なら各表現式は構文解析後評価される前に
    プリントされる．}
  \item{print.eval}{論理値；もし \code{TRUE} なら，
    \code{eval(i)} の結果は各表現式 \code{i} 毎にプリントされる；既定値は
    \code{echo} に値．}
  \item{verbose}{もし \code{TRUE} なら，より多くの診断(単なる 
    \code{echo = TRUE} よりも)が\bold{各}表現式に対する追加の情報を含み
    構文解析と入力の評価の途中でプリントされる．}
  \item{prompt.echo}{文字列；もし \code{echo = TRUE} なら使われるプロンプトを
    与える．}
  \item{max.deparse.length}{整数；\code{echo} が \code{TRUE} の
    時だけ使われ，一つの表現式の逆構文解析に対する出力の最大文字数を与える．}
  \item{chdir}{論理値；もし \code{TRUE} で \code{file} がパス名なら，
    \R の作業ディレクトリは一時的に評価される
    のための \code{file} を含むディレクトリに変更される．}
  \item{encoding}{文字列．\code{file} が文字列の時仮定されるエンコーディング．
    \code{\link{file}} を見よ．可能な値はエンコーディングが推測されるときは
    \code{"unknown"}：\sQuote{エンコーディング}節を見よ．}
  \item{continue.echo}{文字列；\code{echo = TRUE} の時継続行に使われる
    プロンプトを与える．}
  \item{skip.echo}{整数；\code{echo = TRUE} の時ファイルの冒頭のコメント行を
    幾つスキップするか．}
  \item{keep.source}{論理値：もし可能なら，表現式をエコーする時ソース書式
    を保存するか?}
}
\details{
  \code{source} を使ってコードを実行することは，それを \R のコマンドラインから
  入力することと幾つかの点で異なる．
  表現式はトップレベルで実行されないので自動プリントはされない．
  従ってプリントしたいものに対して明示的に \code{print} 呼び出しを
  含める必要がある(そしてこれは \CRANpkg{lattice} によるプロットを含む
  ことを注意する，FAQ Q7.22)．ファイルはその一部を実行する前に全て構文
  解析されるので，構文エラーはコードが全く実行されない結果になる．
  もし構文的に正しいスクリプトの実行中にエラーが起こると，
  実行されたコードにより作業空間中に付値されたものは全て保存される
  (コマンドラインからと同じように)が，\code{\link{traceback}()} のような
  診断情報は \code{\link{withVisible}} への追加の呼び出しを含む．

  \R の全てのバージョンは行の終わりが LF (Unix のような)，
  CRLF (DOS/Windows で使われる)又は CR (クラッシクな Mac OS で使われる)
  でマークされたコネクションからの入力を受け入れ，これを newline に
  マップする．最終行は不完全でも良い，つまり行末マーカーが
  欠損しても良い．

  もし \code{keep.source} が真(対話的な使用では既定値)ならば，
  関数のソースは保存され正確に入力と同じに表示できる．

%   Using \code{echo = TRUE} and \code{keep.source = TRUE} may interact
%   badly with source code that includes \samp{#line nn "filename"}
%   directives (e.g., code produced by older versions of
%   \code{\link{Stangle}()}): \code{source()} will attempt to obtain the
%   source from the named file which may have changed since the code was
%   produced.  Use \code{keep.source = FALSE} to avoid this.

  コンソールからの入力とは異なり，ファイル中やコネクション上の行は
  文字を無制限に含むことが出来る．

  もし \code{skip.echo > 0} なら，ファイルの先頭のその数の行がエコー
  されない．これはコードの実行には全く影響しない．もし最初の \code{skip.echo}
  行に実行行があれば，それらの最初からエコーが始まる．

  もし \code{echo} が真で逆構文解析された表現式が
  \code{max.deparse.length} を超えると，その数の文字が出力され
  その後に \code{ .... [TRUNCATED] } が続く．
}
\section{エンコーディング}{
  既定では入力は \R セッションの現在のエンコーディングで読み込まれ構文解析される．
  これは普通要求されることであるが，時として再エンコーディングが必要になる，
  例えば UTF-8 を使うシステムからのファイルが Windows に読み込まれる時
  (そしてその逆)がそうである．

  このパラグラフの残りは \code{file} が実際のファイル名か URL
  (そして \code{""}  でもなくコネクションでもない)の時に適用される．
  もし \code{encoding = "unknown"} ならエンコーディングを推測しようとする：
  \code{\link{localeToCharset}()} がガイドとして使われる．
  もし \code{encoding} が二つもしくはそれ以上の要素を持てば，
  ファイル/URL が試行されたエンコーディングでエラー無しに読み取れるまで
  それらが順に試される．
  もし実際の \code{encoding} が Latin-1 や UTF-8 中で
  指定されると(既定や \code{"unknown"} で無く)
  結果中の文字列は現在のエンコーディングに翻訳され，
  そうしたものとしてマークされる(\code{\link{Encoding}} を見よ)．

  もし \code{file} がコネクションなら(\code{""} で指定されるものを含む)，
  入力を \code{source} 内部で再エンコーディングすることが出来ず，
  従って \code{encoding} 引数が構文解析された入力中の文字列
  を Latin-1 と UTF-8 ロケールに単にマークするのに使われる：
  \code{\link{parse}} を見よ．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\seealso{
  \code{source} を使う \code{\link{demo}}；
  \code{\link{eval}}, \code{\link{parse}} そして \code{\link{scan}}；
  \code{\link{options}("keep.source")}．

  ファイルを環境中にソースするストリームライン版 \code{\link{sys.source}}．

  ソースのダイレクティブの議論は \sQuote{The R Language Definition}．
}
\examples{
## もし幾つものファイルを source() したければ，次のようにすると役に絶つ
 sourceDir <- function(path, trace = TRUE, ...) {
    for (nm in list.files(path, pattern = "[.][RrSsQq]$")) {
       if(trace) cat(nm,":")
       source(file.path(path, nm), ...)
       if(trace) cat("\n")
    }
 }
}
\keyword{file}
\keyword{programming}
\keyword{connection}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/source.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2012 R Core Team
%% Distributed under GPL 2 or later
%
%\name{source}
%\title{Read R Code from a File or a Connection}
%\description{
%  \code{source} causes \R to accept its input from the named file or URL
%  or connection.  Input is read and \code{\link{parse}}d from that file
%  until the end of the file is reached, then the parsed expressions are
%  evaluated sequentially in the chosen environment.
%}
%\usage{
%source(file, local = FALSE, echo = verbose, print.eval = echo,
%       verbose = getOption("verbose"),
%       prompt.echo = getOption("prompt"),
%       max.deparse.length = 150, chdir = FALSE,
%       encoding = getOption("encoding"),
%       continue.echo = getOption("continue"),
%       skip.echo = 0, keep.source = getOption("keep.source"))
%}
%\alias{source}
%\arguments{
%  \item{file}{a \link{connection} or a character string giving the pathname
%    of the file or URL to read from.  \code{""} indicates the connection
%    \code{\link{stdin}()}.}
%  \item{local}{\code{TRUE}, \code{FALSE} or an environment, determining
%    where the parsed expressions are evaluated.  \code{FALSE} (the
%    default) corresponds to the user's workspace (the global
%    environment) and \code{TRUE} to the environment from which
%    \code{source} is called.}
%  \item{echo}{logical; if \code{TRUE}, each expression is printed
%    after parsing, before evaluation.}
%  \item{print.eval}{logical; if \code{TRUE}, the result of
%    \code{eval(i)} is printed for each expression \code{i}; defaults
%    to the value of \code{echo}.}
%  \item{verbose}{if \code{TRUE}, more diagnostics (than just
%    \code{echo = TRUE}) are printed during parsing and evaluation of
%    input, including extra info for \bold{each} expression.}
%  \item{prompt.echo}{character; gives the prompt to be used if
%    \code{echo = TRUE}.}
%  \item{max.deparse.length}{integer; is used only if \code{echo} is
%    \code{TRUE} and gives the maximal number of characters output for
%    the deparse of a single expression.}
%  \item{chdir}{logical; if \code{TRUE} and \code{file} is a pathname,
%    the \R working directory is temporarily changed to the directory
%    containing \code{file} for evaluating.}
%  \item{encoding}{character vector.  The encoding(s) to be assumed when
%    \code{file} is a character string: see \code{\link{file}}.  A
%    possible value is \code{"unknown"} when the encoding is guessed: see
%    the \sQuote{Encodings} section.}
%  \item{continue.echo}{character; gives the prompt to use on
%    continuation lines if \code{echo = TRUE}.}
%  \item{skip.echo}{integer; how many comment lines at the start of the
%    file to skip if \code{echo = TRUE}.}
%  \item{keep.source}{logical: should the source formatting be retained
%    when echoing expressions, if possible?}
%}
%\details{
%  Note that running code via \code{source} differs in a few respects
%  from entering it at the \R command line.  Since expressions are not
%  executed at the top level, auto-printing is not done.  So you will
%  need to include explicit \code{print} calls for things you want to be
%  printed (and remember that this includes plotting by \CRANpkg{lattice},
%  FAQ Q7.22).  Since the complete file is parsed before any of it is
%  run, syntax errors result in none of the code being run.  If an error
%  occurs in running a syntactically correct script, anything assigned
%  into the workspace by code that has been run will be kept (just as
%  from the command line), but diagnostic information such as
%  \code{\link{traceback}()} will contain additional calls to
%  \code{\link{withVisible}}.
%
%  All versions of \R accept input from a connection with end of line
%  marked by LF (as used on Unix), CRLF (as used on DOS/Windows) or CR
%  (as used on classic Mac OS) and map this to newline.  The final line
%  can be incomplete, that is missing the final end-of-line marker.
%
%  If \code{keep.source} is true (the default in interactive use), the
%  source of functions is kept so they can be listed exactly as input.
%
%%   Using \code{echo = TRUE} and \code{keep.source = TRUE} may interact
%%   badly with source code that includes \samp{#line nn "filename"}
%%   directives (e.g., code produced by older versions of
%%   \code{\link{Stangle}()}): \code{source()} will attempt to obtain the
%%   source from the named file which may have changed since the code was
%%   produced.  Use \code{keep.source = FALSE} to avoid this.
%
%  Unlike input from a console, lines in the file or on a connection can
%  contain an unlimited number of characters.
%
%  When \code{skip.echo > 0}, that many comment lines at the start of
%  the file will not be echoed.  This does not affect the execution of
%  the code at all.  If there are executable lines within the first
%  \code{skip.echo} lines, echoing will start with the first of them.
%
%  If \code{echo} is true and a deparsed expression exceeds
%  \code{max.deparse.length}, that many characters are output followed by
%  \code{ .... [TRUNCATED] }.
%}
%\section{Encodings}{
%  By default the input is read and parsed in  the current encoding of
%  the \R session.  This is usually what it required, but occasionally
%  re-encoding is needed, e.g.\sspace{}if a file from a UTF-8-using system is to
%  be read on Windows (or \emph{vice versa}).
%
%  The rest of this paragraph applies if \code{file} is an actual
%  filename or URL (and not \code{""} nor a connection).  If
%  \code{encoding = "unknown"}, an attempt is made to guess the encoding:
%  the result of \code{\link{localeToCharset}()} is used as a guide.  If
%  \code{encoding} has two or more elements, they are tried in turn until
%  the file/URL can be read without error in the trial encoding.  If an
%  actual \code{encoding} is specified (rather than the default or
%  \code{"unknown"}) in a Latin-1 or UTF-8 locale then character strings
%  in the result will be translated to the current encoding and marked as
%  such (see \code{\link{Encoding}}).
%
%  If \code{file} is a connection (including one specified by \code{""},
%  it is not possible to re-encode the input inside \code{source}, and so
%  the \code{encoding} argument is just used to mark character strings in the
%  parsed input in Latin-1 and UTF-8 locales: see \code{\link{parse}}.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{demo}} which uses \code{source};
%  \code{\link{eval}}, \code{\link{parse}} and \code{\link{scan}};
%  \code{\link{options}("keep.source")}.
%
%  \code{\link{sys.source}} which is a streamlined version to source a
%  file into an environment.
%
%  \sQuote{The R Language Definition} for a discussion of source
%  directives.
%}
%\examples{
%## If you want to source() a bunch of files, something like
%## the following may be useful:
% sourceDir <- function(path, trace = TRUE, ...) {
%    for (nm in list.files(path, pattern = "[.][RrSsQq]$")) {
%       if(trace) cat(nm,":")
%       source(file.path(path, nm), ...)
%       if(trace) cat("\n")
%    }
% }
%}
%\keyword{file}
%\keyword{programming}
%\keyword{connection}
%
\encoding{UTF8}
