% File src/library/base/man/summary.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2011 R Core Team
% Distributed under GPL 2 or later

\name{summary}
\alias{summary}
\alias{summary.default}
\alias{summary.data.frame}
\alias{summary.factor}
\alias{summary.matrix}
\alias{format.summaryDefault}
\alias{print.summaryDefault}
\title{Object Summaries}
\description{
  \code{summary} は様々なモデル当てはめ関数の結果の
  結果サマリーを作るのに使われる総称的関数である．
  この関数はその最初のクラスに関して特定のメソッドを
  起動する．
}
\usage{
summary(object, \dots)

\method{summary}{default}(object, \dots, digits = max(3, getOption("digits")-3))
\method{summary}{data.frame}(object, maxsum = 7,
       digits = max(3, getOption("digits")-3), \dots)

\method{summary}{factor}(object, maxsum = 100, \dots)

\method{summary}{matrix}(object, \dots)
}
\arguments{
  \item{object}{要約したいオブジェクト．}
  \item{maxsum}{整数で，因子に対してどれだけ多くの水準を示すべきかを指示する．}
  \item{digits}{整数で，\code{\link{signif}()} (\code{summary.default} に対して)
    又は \code{\link{format}()}\cr
    (\code{summary.data.frame} に対して)を使う
    数値の整形に使われる．}
  \item{\dots}{作りだされる要約に影響する追加引数．}
}
\details{
    \code{\link{factor}} に対して最初の \code{maxsum - 1} 個の
    最も頻度の高い水準の頻度が示される．そしてより頻度の低い
    水準は \code{"(Others)"} 中に要約する(最大 \code{maxsum} 個の
    頻度になる)．

    関数 \code{summary.lm} と \code{summary.glm} は
    \code{\link{lm}} と \code{\link{glm}} により作られる結果を
    要約する特定のメソッドの例である．
}
\value{
    \code{summary} が返す値の形式はその引数のクラスに依存する．
    そのメソッドにより作られるものについての詳細は
    特定のメソッドのドキュメントを見よ．

    既定のメソッドは特殊化された \code{print} メソッドを持つ，クラス
    \code{c("summaryDefault", "\link{table}")} のオブジェクトを
    返す．

    行列とデータフレームメソッドはクラス \code{"\link{table}"} の
    行列を返す．これは \code{summary} を各列に適用し結果を
    並べることで得られる．
}
\seealso{
  \code{\link{anova}},
  \code{\link{summary.glm}},
  \code{\link{summary.lm}}.
}
\references{
  Chambers, J. M. and Hastie, T. J. (1992)
  \emph{Statistical Models in S}.
  Wadsworth & Brooks/Cole.
}
\examples{
summary(attenu, digits = 4) #-> summary.data.frame(...), 既定の精度
summary(attenu $ station, maxsum = 20) #-> summary.factor(...)

lst <- unclass(attenu$station) > 20 # NA を持つ論理値
## 論理値に対する summary.default() -- *.factor と異なる：
summary(lst)
summary(as.factor(lst))
}
\keyword{methods}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/summary.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2011 R Core Team
%% Distributed under GPL 2 or later
%
%\name{summary}
%\alias{summary}
%\alias{summary.default}
%\alias{summary.data.frame}
%\alias{summary.factor}
%\alias{summary.matrix}
%\alias{format.summaryDefault}
%\alias{print.summaryDefault}
%\title{Object Summaries}
%\description{
%  \code{summary} is a generic function used to produce result summaries
%  of the results of various model fitting functions.  The function
%  invokes particular \code{\link{methods}} which depend on the
%  \code{\link{class}} of the first argument.
%}
%\usage{
%summary(object, \dots)
%
%\method{summary}{default}(object, \dots, digits = max(3, getOption("digits")-3))
%\method{summary}{data.frame}(object, maxsum = 7,
%       digits = max(3, getOption("digits")-3), \dots)
%
%\method{summary}{factor}(object, maxsum = 100, \dots)
%
%\method{summary}{matrix}(object, \dots)
%}
%\arguments{
%  \item{object}{an object for which a summary is desired.}
%  \item{maxsum}{integer, indicating how many levels should be shown for
%    \code{\link{factor}}s.}
%  \item{digits}{integer, used for number formatting with
%    \code{\link{signif}()} (for \code{summary.default}) or
%    \code{\link{format}()} (for \code{summary.data.frame}).}
%  \item{\dots}{additional arguments affecting the summary produced.}
%}
%\details{
%    For \code{\link{factor}}s, the frequency of the first \code{maxsum - 1}
%    most frequent levels is shown, and the less frequent levels are
%    summarized in \code{"(Others)"} (resulting in at most \code{maxsum}
%    frequencies).
%
%    The functions \code{summary.lm} and \code{summary.glm} are examples
%    of particular methods which summarize the results produced by
%    \code{\link{lm}} and \code{\link{glm}}.
%}
%\value{
%    The form of the value returned by \code{summary} depends on the
%    class of its argument.  See the documentation of the particular
%    methods for details of what is produced by that method.
%
%    The default method returns an object of class
%    \code{c("summaryDefault", "\link{table}")} which has a specialized
%    \code{print} method.  The \code{\link{factor}} method returns an
%    integer vector.
%
%    The matrix and data frame methods return a matrix of class
%    \code{"\link{table}"}, obtained by applying \code{summary} to each
%    column and collating the results.
%}
%\seealso{
%  \code{\link{anova}},
%  \code{\link{summary.glm}},
%  \code{\link{summary.lm}}.
%}
%\references{
%  Chambers, J. M. and Hastie, T. J. (1992)
%  \emph{Statistical Models in S}.
%  Wadsworth & Brooks/Cole.
%}
%\examples{
%summary(attenu, digits = 4) #-> summary.data.frame(...), default precision
%summary(attenu $ station, maxsum = 20) #-> summary.factor(...)
%
%lst <- unclass(attenu$station) > 20 # logical with NAs
%## summary.default() for logicals -- different from *.factor:
%summary(lst)
%summary(as.factor(lst))
%}
%\keyword{methods}
%
\encoding{UTF8}
