% File src/library/base/man/sys.source.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{sys.source}
\alias{sys.source}
\title{Parse and Evaluate Expressions from a File}
\description{
  与えられたファイル中の表現式を構文解析し，それからそれらを指定された環境
  中で次々と評価する．
}
\usage{
sys.source(file, envir = baseenv(), chdir = FALSE,
           keep.source = getOption("keep.source.pkgs"))
}
\arguments{
  \item{file}{読み込まれるファイルの名前である文字列．}
  \item{envir}{表現式がその中で評価される環境を指定する \R オブジェクト．
    リストや整数かもしれない．
    既定値の \code{NULL} は基本環境中での評価に対応する．
    これは恐らく希望するものではない：典型的には
    \code{envir} 引数を明示的に提供するべきである．}
  \item{chdir}{論理値；もし \code{TRUE} ならば，\R の作業ディレクトリ
    は評価される \code{file} を含むディレクトリに変更された．}
  \item{keep.source}{論理値．もし \code{TRUE} なら関数はコメントを含む
    それらのソースを保存する．より詳細は
    \code{\link{options}(keep.source = *)} を見よ．}
}
\details{
  大きなファイルに対しては \code{keep.source = FALSE} は相当の量の
  メモリを節約する．
%%FIXME:  the following paragraph should be somewhere it's likely to be seen
  評価されるコードが正しい環境
  (例えば大局的環境)を使うためには，パッケージ中のソースコードは
  \code{\link{topenv}()} を呼び出すべきである．これは
  もしあれば名前空間，\code{sys.source} で設定された 環境，又は
  もし保存されたイメージが使われるならば大局的環境，を返す．
}
\seealso{\code{\link{source}}，そして \code{sys.source} を使う \code{\link{library}}．
}
\examples{
## 幾つかのオブジェクトを検索パス上高い位置にある環境に置く簡単な方法
tmp <- tempfile()
writeLines("aaa <- pi", tmp)
env <- attach(NULL, name = "myenv")
sys.source(tmp, env)
unlink(tmp)
search()
aaa
detach("myenv")
}
\keyword{file}
\keyword{utilities}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/sys.source.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{sys.source}
%\alias{sys.source}
%\title{Parse and Evaluate Expressions from a File}
%\description{
%  Parses expressions in the given file, and then successively evaluates
%  them in the specified environment.
%}
%\usage{
%sys.source(file, envir = baseenv(), chdir = FALSE,
%           keep.source = getOption("keep.source.pkgs"))
%}
%\arguments{
%  \item{file}{a character string naming the file to be read from}
%  \item{envir}{an \R object specifying the environment in which the
%    expressions are to be evaluated.  May also be a list or an integer.
%    The default value \code{NULL} corresponds to evaluation in the base
%    environment.  This is probably not what you want; you should
%    typically supply an explicit \code{envir} argument.}
%  \item{chdir}{logical; if \code{TRUE}, the \R working directory is
%    changed to the directory containing \code{file} for evaluating.}
%  \item{keep.source}{logical.  If \code{TRUE}, functions keep
%    their source including comments, see
%    \code{\link{options}(keep.source = *)} for more details.}
%}
%\details{
%  For large files, \code{keep.source = FALSE} may save quite a bit of
%  memory.
%%%FIXME:  the following paragraph should be somewhere it's likely to be seen
%  In order for the code being evaluated to use the correct environment
%  (for example, in global assignments), source code in packages should
%  call \code{\link{topenv}()}, which will return the namespace, if any,
%  the environment set up by \code{sys.source}, or the global environment
%  if a saved image is being used.
%}
%\seealso{\code{\link{source}}, and \code{\link{library}} which uses
%  \code{sys.source}.
%}
%\examples{
%## a simple way to put some objects in an environment
%## high on the search path
%tmp <- tempfile()
%writeLines("aaa <- pi", tmp)
%env <- attach(NULL, name = "myenv")
%sys.source(tmp, env)
%unlink(tmp)
%search()
%aaa
%detach("myenv")
%}
%\keyword{file}
%\keyword{utilities}
%\encoding{UTF8}

\encoding{UTF8}

