% File src/library/graphics/man/plot.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{plot}
\title{Generic X-Y Plotting}
\alias{plot}
\description{
  \R オブジェクトをプロットする総称的関数．
  グラフィカルパラメータのより詳細については
  \code{\link{par}} を見よ．

  単純な散布図に対しては \code{\link{plot.default}} が使われる．
  しかしながら \code{\link{function}}, \code{\link{data.frame}},
  \code{\link{density}} オブジェクト等，
  多くの \R オブジェクトに対して \code{plot} メソッドがある．
  \code{methods(plot)} を使いそれらのドキュメントを見よ．
}
\usage{
plot(x, y, \dots)
}
\arguments{
  \item{x}{プロット中の点の座標．又は
      単一のプロット構造，関数，もしくは
        \emph{\code{plot} メソッドを持つ任意の \R オブジェクト}を与えることができる．}
  \item{y}{プロット中の点の座標，
    もし \code{x} は適当な構造，\emph{オプション}}
  \item{\dots}{グラフィカルパラメータ等のメソッドに渡される引数
    (\code{\link{par}} を見よ)．
    多くのメソッドは以下の引数を受け付ける：
    \describe{
    \item{\code{type}}{どのようなプロットが描かれるべきか．
      可能なタイプは 
      \itemize{
        \item \code{"p"} 点に対して，
        \item \code{"l"} 線に対して，
        \item \code{"b"} 双方に対して，
        \item \code{"c"} \code{"b"} の線部分だけに対して，
        \item \code{"o"} 双方の\sQuote{重ねプロット}に対して，
        \item \code{"h"} \sQuote{ヒストグラム}風の
	  (又は\sQuote{高密度})の垂直線に対して，
        \item \code{"s"} 階段ステップに対して，
        \item \code{"S"} 他のステップに対して，下の\sQuote{詳細}を見よ，
        \item \code{"n"} プロットなしに対して．
      }
      他の全ての \code{type} は警告かエラーを与える；例えば S との互換性から
      \code{type = "punkte"} は \code{type = "p"} と同値である．
      例えば \code{\link{plot.factor}} のようなある種のメソッドは
      これを受け付けない．
    }
    \item{\code{main}}{プロットに対する全体的タイトル：\code{\link{title}} を見よ．}
    \item{\code{sub}}{プロットに対する副タイトル：\code{\link{title}} を見よ．}
    \item{\code{xlab}}{x 軸に対する全体的タイトル：\code{\link{title}} を見よ．}
    \item{\code{ylab}}{y 軸に対する全体的タイトル：\code{\link{title}} を見よ．}
    \item{\code{asp}}{アスペクト比 \eqn{y/x}，\code{\link{plot.window}} を見よ．}
    }
  }
}
\details{
  二つのステップのタイプはそれらの x-y 優先順序が異なる：
  \eqn{x1 < x2} の場合の \eqn{(x1,y1)} から \eqn{(x2,y2)} へ，
  \code{type = "s"} では最初水平に，次に垂直に動く．
  他方で \code{type = "S"} は他の方法で動く．
}
\seealso{
  \code{\link{plot.default}}, \code{\link{plot.formula}} そして他のメソッド；
  \code{\link{points}}, \code{\link{lines}}, \code{\link{par}}.
  数千の点に対しては \code{plot()} の代わりに
  \code{\link{smoothScatter}()} を考えてみよう．

  X-Y-Z プロットについては \code{\link{contour}}, \code{\link{persp}} そして
  \code{\link{image}} を見よ．
}
\examples{
require(stats) # lowess, rpois, rnorm のため
plot(cars)
lines(lowess(cars))

plot(sin, -pi, 2*pi) # ?plot.function を見る

## 離散分布プロット：
plot(table(rpois(100, 5)), type = "h", col = "red", lwd = 10,
     main = "rpois(100, lambda = 5)")

## 簡単な クォンタイル/ECDF, より良い物は ecdf() {library(stats)} を見よ：
plot(x <- sort(rnorm(47)), type = "s", main = "plot(x, type = \"s\")")
points(x, cex = .5, col = "dark red")
}
\keyword{hplot}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/graphics/man/plot.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{plot}
%\title{Generic X-Y Plotting}
%\alias{plot}
%\description{
%  Generic function for plotting of \R objects.  For more details about
%  the graphical parameter arguments, see \code{\link{par}}.
%
%  For simple scatter plots, \code{\link{plot.default}} will be used.
%  However, there are \code{plot} methods for many \R objects,
%  including \code{\link{function}}s, \code{\link{data.frame}}s,
%  \code{\link{density}} objects, etc.  Use \code{methods(plot)} and
%  the documentation for these.
%}
%\usage{
%plot(x, y, \dots)
%}
%\arguments{
%  \item{x}{the coordinates of points in the plot. Alternatively, a
%      single plotting structure, function or \emph{any \R object with a
%        \code{plot} method} can be provided.}
%  \item{y}{the y coordinates of points in the plot, \emph{optional}
%    if \code{x} is an appropriate structure.}
%  \item{\dots}{Arguments to be passed to methods, such as
%    \link{graphical parameters} (see \code{\link{par}}).
%    Many methods will accept the following arguments:
%    \describe{
%    \item{\code{type}}{what type of plot should be drawn.  Possible types are
%      \itemize{
%        \item \code{"p"} for \bold{p}oints,
%        \item \code{"l"} for \bold{l}ines,
%        \item \code{"b"} for \bold{b}oth,
%        \item \code{"c"} for the lines part alone of \code{"b"},
%        \item \code{"o"} for both \sQuote{\bold{o}verplotted},
%        \item \code{"h"} for \sQuote{\bold{h}istogram} like (or
%        \sQuote{high-density}) vertical lines,
%        \item \code{"s"} for stair \bold{s}teps,
%        \item \code{"S"} for other \bold{s}teps, see \sQuote{Details} below,
%        \item \code{"n"} for no plotting.
%      }
%      All other \code{type}s give a warning or an error; using, e.g.,
%      \code{type = "punkte"} being equivalent to \code{type = "p"} for S
%      compatibility.  Note that some methods,
%      e.g.\sspace{}\code{\link{plot.factor}}, do not accept this.
%    }
%    \item{\code{main}}{an overall title for the plot: see \code{\link{title}}.}
%    \item{\code{sub}}{a sub title for the plot: see \code{\link{title}}.}
%    \item{\code{xlab}}{a title for the x axis: see \code{\link{title}}.}
%    \item{\code{ylab}}{a title for the y axis: see \code{\link{title}}.}
%    \item{\code{asp}}{the \eqn{y/x} aspect ratio,
%      see \code{\link{plot.window}}.}
%    }
%  }
%}
%\details{
%  The two step types differ in their x-y preference: Going from
%  \eqn{(x1,y1)} to \eqn{(x2,y2)} with \eqn{x1 < x2}, \code{type = "s"}
%  moves first horizontal, then vertical, whereas \code{type = "S"} moves
%  the other way around.
%}
%\seealso{
%  \code{\link{plot.default}}, \code{\link{plot.formula}} and other
%  methods; \code{\link{points}}, \code{\link{lines}}, \code{\link{par}}.
%  For thousands of points, consider using \code{\link{smoothScatter}()}
%  instead of \code{plot()}.
%
%  For X-Y-Z plotting see \code{\link{contour}}, \code{\link{persp}} and
%  \code{\link{image}}.
%}
%\examples{
%require(stats) # for lowess, rpois, rnorm
%plot(cars)
%lines(lowess(cars))
%
%plot(sin, -pi, 2*pi) # see ?plot.function
%
%## Discrete Distribution Plot:
%plot(table(rpois(100, 5)), type = "h", col = "red", lwd = 10,
%     main = "rpois(100, lambda = 5)")
%
%## Simple quantiles/ECDF, see ecdf() {library(stats)} for a better one:
%plot(x <- sort(rnorm(47)), type = "s", main = "plot(x, type = \"s\")")
%points(x, cex = .5, col = "dark red")
%}
%\keyword{hplot}
%
%\encoding{UTF8}
%