% File src/library/graphics/man/polygon.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2011 R Core Team
% Distributed under GPL 2 or later

\name{polygon}
\alias{polygon}
\title{Polygon Drawing}
\description{
  \code{polygon} は頂点が
  \code{x} と \code{y} 中で与えられる多角形を描く．

}
\usage{
polygon(x, y = NULL, density = NULL, angle = 45,
        border = NULL, col = NA, lty = par("lty"),
        \dots, fillOddEven = FALSE)
}
\arguments{
  \item{x, y}{多角形の頂点の座標を含むベクトル．}
  \item{density}{陰影線の密度，インチあたりの線数．
    既定値 \code{NULL} は陰影線を描かないことを意味する
    \code{density} がゼロなら陰影も塗りつぶしもせず，
    負の値と \code{NA} は陰影を抑制する(そして色による塗りつぶしは認める．}
  \item{angle}{陰影線の傾き，度による角度で与える(反時計回り)．}
   \item{col}{
     多角形を塗りつぶす色．既定の \code{NA} は \code{density} が指定されない限り
     多角形を塗りつぶさない．
     (後方互換性のため \code{NULL} は \code{NA} と同値である．)
     もし正の \code{density} が指定されるとそれは
     射影線の色を与える．}
  \item{border}{輪郭を描く色．
    既定の \code{NULL} は \code{\link{par}("fg")} の使用を意味する．
    輪郭を無くすには \code{border = NA} を使う．

    S との互換性のため \code{border} は論理値でもよく，
    その場合 \code{FALSE} は \code{NA} に等しく(輪郭を描かない)
    \code{TRUE} は \code{NULL} に等しい(前景色を使用)．}
      \item{lty}{\code{\link{par}} に於けるような使用される線種．}
  \item{\dots}{\code{xpd}, \code{lend}, \code{ljoin} そして \code{lmitre}
    の様なグラフィカルパラメータを引数として与えることが出来る．}
  \item{fillOddEven}{多角形の陰影モードを制御する論理値：
    下を見よ，既定値は \code{FALSE}．}
}
\details{
  座標はプロット構造
  (\code{x} と \code{y} 成分を持つリスト)，二列の行列，\dots などとして
  渡すことが出来る．\code{\link{xy.coords}} を見よ．

  多角形は最後の点を最初の点と結んだ閉多角形と仮定される．

  座標は欠損値を含むことが出来る．
  その挙動は \code{\link{lines}} のそれに似るが，
  線を幾つかの線に分断する代わりに，
  \code{NA} 値は多角形を幾つかの完全な多角形に分割する
  (それぞれが最初と最後の点を結び閉じている)．下の例を見よ．

  複数の多角形が作られると，
  \code{density}, \code{angle}, \code{col}, \code{border} そして
  \code{lty} の値は通常のようにリサイクルされる．

  多角形の陰影化は線形なプロットに対してだけ実装されている：
  もしどちらかの軸が対数スケールならば陰影化は警告と共に行われない．
}
\section{バグ}{
  自己交差多角形は
  \dQuote{odd-even} か \dQuote{non-zero} 規則のどちらかを使って
  塗りつぶされるかもしれない．これらは領域をそれぞれ
  もし多角形の境界がそれを奇数回又は一回以上一周すれば塗りつぶす．
  陰影線は \code{fillOddEven} 引数に従って内部的に \R{} で処理されるが，
  デバイスベースの実線による塗りつぶしはグラフィックスデバイスに
  依存する．
  \code{windows}, \code{\link{pdf}}
  そして \code{\link{postscript}} デバイスはこれを制御する
  それら自体の \code{fillOddEven} を持つ．
}
\author{
  多角形の陰影化を実装するコードは
  Kevin Buhr \email{buhr@stat.wisc.edu} による．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.

  Murrell, P. (2005) \emph{R Graphics}. Chapman & Hall/CRC Press.
}
\seealso{
  より柔軟な \code{\link{segments}}, \code{\link{lines}},
  \code{\link{rect}}, \code{\link{box}}, \code{\link{abline}}.

  色の指定法は \code{\link{par}}．
}
\examples{
x <- c(1:9, 8:1)
y <- c(1, 2*(5:3), 2, -1, 17, 9, 8, 2:9)
op <- par(mfcol = c(3, 1))
for(xpd in c(FALSE, TRUE, NA)) {
  plot(1:10, main = paste("xpd =", xpd))
  box("figure", col = "pink", lwd = 3)
  polygon(x, y, xpd = xpd, col = "orange", lty = 2, lwd = 2, border = "red")
}
par(op)

n <- 100
xx <- c(0:n, n:0)
yy <- c(c(0, cumsum(stats::rnorm(n))), rev(c(0, cumsum(stats::rnorm(n)))))
plot   (xx, yy, type = "n", xlab = "Time", ylab = "Distance")
polygon(xx, yy, col = "gray", border = "red")
title("Distance Between Brownian Motions")

# NA 値からの複数の多角形
# and recycling of col, border, and lty
op <- par(mfrow = c(2, 1))
plot(c(1, 9), 1:2, type = "n")
polygon(1:9, c(2,1,2,1,1,2,1,2,1),
        col = c("red", "blue"),
        border = c("green", "yellow"),
        lwd = 3, lty = c("dashed", "solid"))
plot(c(1, 9), 1:2, type = "n")
polygon(1:9, c(2,1,2,1,NA,2,1,2,1),
        col = c("red", "blue"),
        border = c("green", "yellow"),
        lwd = 3, lty = c("dashed", "solid"))
par(op)

# 線で陰影をつけた多角形
plot(c(1, 9), 1:2, type = "n")
polygon(1:9, c(2,1,2,1,NA,2,1,2,1),
        density = c(10, 20), angle = c(-45, 45))
}
\keyword{aplot}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/graphics/man/polygon.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2011 R Core Team
%% Distributed under GPL 2 or later
%
%\name{polygon}
%\alias{polygon}
%\title{Polygon Drawing}
%\description{
%  \code{polygon} draws the polygons whose vertices are
%  given in \code{x} and \code{y}.
%}
%\usage{
%polygon(x, y = NULL, density = NULL, angle = 45,
%        border = NULL, col = NA, lty = par("lty"),
%        \dots, fillOddEven = FALSE)
%}
%\arguments{
%  \item{x, y}{vectors containing the coordinates of the vertices
%    of the polygon.}
%  \item{density}{the density of shading lines, in lines per inch.  The
%    default value of \code{NULL} means that no shading lines are drawn.
%    A zero value of \code{density} means no shading nor filling whereas
%    negative values and \code{NA} suppress shading (and so allow
%    color filling).}
%  \item{angle}{the slope of shading lines, given as an angle
%     in degrees (counter-clockwise).}
%   \item{col}{the color for filling the polygon. The default,
%     \code{NA}, is to leave polygons unfilled, unless \code{density} is
%     specified.  (For back-compatibility, \code{NULL} is equivalent to
%     \code{NA}.)  If \code{density} is specified with a positive value
%     this gives the color of the shading lines.}
%  \item{border}{the color to draw the border.  The default, \code{NULL},
%    means to use \code{\link{par}("fg")}.  Use \code{border = NA} to
%    omit borders.
%
%    For compatibility with S, \code{border} can also be logical, in
%    which case \code{FALSE} is equivalent to \code{NA} (borders omitted)
%    and \code{TRUE} is equivalent to \code{NULL} (use the foreground colour),
%  }
%  \item{lty}{the line type to be used, as in \code{\link{par}}.}
%  \item{\dots}{graphical parameters such as \code{xpd}, \code{lend},
%    \code{ljoin} and \code{lmitre} can be given as arguments.}
%  \item{fillOddEven}{logical controlling the polygon shading mode:  see
%      below for details.  Default \code{FALSE}.}
%}
%\details{
%  The coordinates can be passed in a plotting structure
%  (a list with \code{x} and \code{y} components), a two-column matrix,
%  \dots.  See \code{\link{xy.coords}}.
%
%  It is assumed that the polygon is to be closed by joining the last
%  point to the first point.
%
%  The coordinates can contain missing values.  The behaviour is similar
%  to that of \code{\link{lines}}, except that instead of breaking a line
%  into several lines, \code{NA} values break the polygon into several
%  complete polygons (including closing the last point to the first
%  point).  See the examples below.
%
%  When multiple polygons are produced, the values of \code{density},
%  \code{angle}, \code{col}, \code{border}, and \code{lty} are recycled
%  in the usual manner.
%
%  Shading of polygons is only implemented for linear plots: if either
%  axis is on log scale then shading is omitted, with a warning.
%}
%\section{Bugs}{
%  Self-intersecting polygons may be filled using either the
%  \dQuote{odd-even} or \dQuote{non-zero} rule.  These fill a region if
%  the polygon border encircles it an odd or non-zero number of times,
%  respectively.  Shading lines are handled internally by \R{} according
%  to the \code{fillOddEven} argument, but device-based solid fills
%  depend on the graphics device.  The \code{windows}, \code{\link{pdf}}
%  and \code{\link{postscript}} devices have their own \code{fillOddEven}
%  argument to control this.
%}
%\author{
%  The code implementing polygon shading was donated by
%  Kevin Buhr \email{buhr@stat.wisc.edu}.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%
%  Murrell, P. (2005) \emph{R Graphics}. Chapman & Hall/CRC Press.
%}
%\seealso{
%  \code{\link{segments}} for even more flexibility, \code{\link{lines}},
%  \code{\link{rect}}, \code{\link{box}}, \code{\link{abline}}.
%
%  \code{\link{par}} for how to specify colors.
%}
%\examples{
%x <- c(1:9, 8:1)
%y <- c(1, 2*(5:3), 2, -1, 17, 9, 8, 2:9)
%op <- par(mfcol = c(3, 1))
%for(xpd in c(FALSE, TRUE, NA)) {
%  plot(1:10, main = paste("xpd =", xpd))
%  box("figure", col = "pink", lwd = 3)
%  polygon(x, y, xpd = xpd, col = "orange", lty = 2, lwd = 2, border = "red")
%}
%par(op)
%
%n <- 100
%xx <- c(0:n, n:0)
%yy <- c(c(0, cumsum(stats::rnorm(n))), rev(c(0, cumsum(stats::rnorm(n)))))
%plot   (xx, yy, type = "n", xlab = "Time", ylab = "Distance")
%polygon(xx, yy, col = "gray", border = "red")
%title("Distance Between Brownian Motions")
%
%# Multiple polygons from NA values
%# and recycling of col, border, and lty
%op <- par(mfrow = c(2, 1))
%plot(c(1, 9), 1:2, type = "n")
%polygon(1:9, c(2,1,2,1,1,2,1,2,1),
%        col = c("red", "blue"),
%        border = c("green", "yellow"),
%        lwd = 3, lty = c("dashed", "solid"))
%plot(c(1, 9), 1:2, type = "n")
%polygon(1:9, c(2,1,2,1,NA,2,1,2,1),
%        col = c("red", "blue"),
%        border = c("green", "yellow"),
%        lwd = 3, lty = c("dashed", "solid"))
%par(op)
%
%# Line-shaded polygons
%plot(c(1, 9), 1:2, type = "n")
%polygon(1:9, c(2,1,2,1,NA,2,1,2,1),
%        density = c(10, 20), angle = c(-45, 45))
%}
%\keyword{aplot}
%
%\encoding{UTF8}
%