% File src/library/graphics/man/stripchart.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{stripchart}
\title{1-D Scatter Plots}
\alias{stripchart}
\alias{stripchart.default}
\alias{stripchart.formula}

\description{
  \code{stripchart} は与えられたデータの一次元散布図
  (またはドットプロット)を作る．これらのプロットは
  標本数が小さい時
  \code{\link{boxplot}} の良い代替物である．
}
\usage{
stripchart(x, \dots)

\method{stripchart}{formula}(x, data = NULL, dlab = NULL, \dots,
           subset, na.action = NULL)


\method{stripchart}{default}(x, method = "overplot", jitter = 0.1, offset = 1/3,
           vertical = FALSE, group.names, add = FALSE,
           at = NULL, xlim = NULL, ylim = NULL,
           ylab = NULL, xlab = NULL, dlab = "", glab = "",
           log = "", pch = 0, col = par("fg"), cex = par("cex"),
           axes = TRUE, frame.plot = axes, \dots)
}
\arguments{
  \item{x}{プロットをそれから作るデータ．
    既定メソッドではデータは単一の数値ベクトルか，
    各々が成分のプロットに対応する数値ベクトルのリスト．
    \code{formula} メソッドでは
    \code{y ~ g} の形式のシンボリックな指定が可能で，
    ベクトル \code{y} 中の観測値が
    因子 \code{g} の水準に従ってグループ化されることを指示する．
    データ中には \code{NA} が許される．}
  \item{data}{
    \code{x} 中の変数がそこから取られるデータフレーム(又はリスト)．}
  \item{subset}{プロットに使われる観測値の部分集合を指定するオプションのベクトル．}
  \item{na.action}{
    データが \code{NA} を含む時何が起こるかを指示する関数．
    既定では応答変数でもグループでも欠損値を無視する．}
  \item{\dots}{既定メソッドに渡される追加パラメータ，もしくは
    プロットの外見を制御する
    \code{\link{plot.window}}, \code{\link{points}},
    \code{\link{axis}} そして \code{\link{title}} へのパラメータ．}
  \item{method}{同一の点を区別するのに使われるメソッド．
    既定メソッド \code{"overplot"} はそうした点を重ね描きするが，
    点を少しずらす \code{"jitter"} や，
    同一の点を積み重ねる \code{"stack"} も利用できる．
    最後のメソッドは非常に顆粒状のデータに対してだけ意味を持つ．}
  \item{jitter}{\code{method = "jitter"} が使われた時，
    \code{jitter} は適用されるずらしの量を与える．}
  \item{offset}{積み重ねが使われる時，点は
    この行高(シンボル幅)だけ離れて積み重ねられる．}
  \item{vertical}{
    \code{TRUE} ならばプロットは既定の水平ではなく垂直に描かれる．}
  \item{group.names}{各プロットに沿って(又は下に)プリントされる
    グループラベル．}
  \item{add}{論理値，もし真なら現在のプロットに図を\emph{加える}．}
  \item{at}{図が描かれる位置を与える数値ベクトル，
    特に \code{add = TRUE} の時；
    既定値は \code{1:n} でここで \code{n} はボックスの数．}
  \item{ylab, xlab}{ラベル：\code{\link{title}} を見よ．}
  \item{dlab, glab}{軸ラベルを指定する別法：sQuote{Details} を見よ．}
  \item{xlim, ylim}{プロットの限界：\code{\link{plot.window}} を見よ．}
  \item{log}{どの軸に対数スケールを使うか：
    \code{\link{plot.default}} を見よ．}
  \item{pch, col, cex}{グラフィカルパラメータ：\code{\link{par}} を見よ．}
  \item{axes, frame.plot}{軸の制御：\code{\link{plot.default}} を見よ．}
}
\details{
  この種のプロットの使用の広範囲の例が
  Box, Hunter and Hunter または Seber and Wild にある．

  code{dlab} と \code{glab} ラベルは，もしこれらが指定されていなければ
  \code{xlab} と \code{ylab} の代わりに使うことが出来る．
  \code{dlab} は連続的なデータ軸
  (\code{vertical} が \code{TRUE} で無い限り X 軸)に，
  \code{glab} はグループ軸に適用される．
}
\examples{
x <- stats::rnorm(50)
xr <- round(x, 1)
stripchart(x) ; m <- mean(par("usr")[1:2])
text(m, 1.04, "stripchart(x, \"overplot\")")
stripchart(xr, method = "stack", add = TRUE, at = 1.2)
text(m, 1.35, "stripchart(round(x,1), \"stack\")")
stripchart(xr, method = "jitter", add = TRUE, at = 0.7)
text(m, 0.85, "stripchart(round(x,1), \"jitter\")")

stripchart(decrease ~ treatment,
    main = "stripchart(OrchardSprays)",
    vertical = TRUE, log = "y", data = OrchardSprays)

stripchart(decrease ~ treatment, at = c(1:8)^2,
    main = "stripchart(OrchardSprays)",
    vertical = TRUE, log = "y", data = OrchardSprays)
}
\keyword{hplot}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/graphics/man/stripchart.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{stripchart}
%\title{1-D Scatter Plots}
%\alias{stripchart}
%\alias{stripchart.default}
%\alias{stripchart.formula}
%
%\description{
%  \code{stripchart} produces one dimensional scatter plots (or dot
%  plots) of the given data.  These plots are a good alternative to
%  \code{\link{boxplot}}s when sample sizes are small.
%}
%\usage{
%stripchart(x, \dots)
%
%\method{stripchart}{formula}(x, data = NULL, dlab = NULL, \dots,
%           subset, na.action = NULL)
%
%
%\method{stripchart}{default}(x, method = "overplot", jitter = 0.1, offset = 1/3,
%           vertical = FALSE, group.names, add = FALSE,
%           at = NULL, xlim = NULL, ylim = NULL,
%           ylab = NULL, xlab = NULL, dlab = "", glab = "",
%           log = "", pch = 0, col = par("fg"), cex = par("cex"),
%           axes = TRUE, frame.plot = axes, \dots)
%}
%\arguments{
%  \item{x}{the data from which the plots are to be produced.  In the
%    default method the data can be specified as a single numeric
%    vector, or as list of numeric vectors, each corresponding to
%    a component plot.  In the \code{formula} method, a symbolic
%    specification of the form \code{y ~ g} can be given,
%    indicating the observations in the vector \code{y} are to be
%    grouped according to the levels of the factor
%    \code{g}.  \code{NA}s are allowed in the data.}
%  \item{data}{a data.frame (or list) from which the variables in
%    \code{x} should be taken.}
%  \item{subset}{an optional vector specifying a subset of observations
%    to be used for plotting.}
%  \item{na.action}{a function which indicates what should happen
%    when the data contain \code{NA}s.  The default is to ignore missing
%    values in either the response or the group.}
%  \item{\dots}{additional parameters passed to the default method, or by
%    it to \code{\link{plot.window}}, \code{\link{points}},
%    \code{\link{axis}} and \code{\link{title}} to control the appearance
%    of the plot.} 
%  \item{method}{the method to be used to separate coincident points.
%    The default method \code{"overplot"} causes such points to be
%    overplotted, but it is also possible to specify \code{"jitter"} to
%    jitter the points, or \code{"stack"} have coincident points
%    stacked.  The last method only makes sense for very granular data.}
%  \item{jitter}{when \code{method = "jitter"} is used, \code{jitter}
%    gives the amount of jittering applied.}
%  \item{offset}{when stacking is used, points are stacked this many
%    line-heights (symbol widths) apart.}
%  \item{vertical}{when vertical is \code{TRUE} the plots are drawn
%    vertically rather than the default horizontal.}
%  \item{group.names}{group labels which will be printed alongside
%    (or underneath) each plot.}
%  \item{add}{logical, if true \emph{add} the chart to the current plot.}
%  \item{at}{numeric vector giving the locations where the charts should
%    be drawn, particularly when \code{add = TRUE};
%    defaults to \code{1:n} where \code{n} is the number of boxes.}
%  \item{ylab, xlab}{labels: see \code{\link{title}}.}
%  \item{dlab, glab}{alternate way to specify axis labels: see \sQuote{Details}.}
%  \item{xlim, ylim}{plot limits: see \code{\link{plot.window}}.}
%  \item{log}{on which axes to use a log scale:  see
%    \code{\link{plot.default}}}
%  \item{pch, col, cex}{Graphical parameters: see \code{\link{par}}.}
%  \item{axes, frame.plot}{Axis control:  see \code{\link{plot.default}}.}
%}
%\details{
%  Extensive examples of the use of this kind of plot can be found in
%  Box, Hunter and Hunter or Seber and Wild.
%
%  The \code{dlab} and \code{glab} labels may be used instead of \code{xlab}
%  and \code{ylab} if those are not specified.  \code{dlab} applies to the
%  continuous data axis (the X axis unless \code{vertical} is \code{TRUE}),
%  \code{glab} to the group axis.
%}
%\examples{
%x <- stats::rnorm(50)
%xr <- round(x, 1)
%stripchart(x) ; m <- mean(par("usr")[1:2])
%text(m, 1.04, "stripchart(x, \"overplot\")")
%stripchart(xr, method = "stack", add = TRUE, at = 1.2)
%text(m, 1.35, "stripchart(round(x,1), \"stack\")")
%stripchart(xr, method = "jitter", add = TRUE, at = 0.7)
%text(m, 0.85, "stripchart(round(x,1), \"jitter\")")
%
%stripchart(decrease ~ treatment,
%    main = "stripchart(OrchardSprays)",
%    vertical = TRUE, log = "y", data = OrchardSprays)
%
%stripchart(decrease ~ treatment, at = c(1:8)^2,
%    main = "stripchart(OrchardSprays)",
%    vertical = TRUE, log = "y", data = OrchardSprays)
%}
%\keyword{hplot}
%
%\encoding{UTF8}
%