% File src/library/graphics/man/strwidth.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2011 R Core Team
% Distributed under GPL 2 or later

\name{strwidth}
\title{Plotting Dimensions of Character Strings and Math Expressions}
\description{
  これらの関数は与えられた文字列もしくは数学表現式
  \code{s[i]} の
  現在のプロットデバイス上の\emph{ユーザ}座標での幅と高さをそれぞれ計算する，
  単位は\emph{インチ}か図幅 \code{par("fin")} に対する割合である．
}
\usage{
strwidth(s, units = "user", cex = NULL, font = NULL, vfont = NULL, ...)
strheight(s, units = "user", cex = NULL, font = NULL, vfont = NULL, ...)
}
\alias{strwidth}
\alias{strheight}
\arguments{
  \item{s}{その大きさを測定したい文字列または表現式ベクトル．
    他のオブエックとは \code{\link{as.graphicsAnnot}} で強制変換される．}
  \item{units}{
    どの単位で \code{s} を測定するかを指示する文字列：
    \code{"user"}, \code{"inches"}, \code{"figure"} のどれか
    でなければならない；部分マッチングが行われる．}
  \item{cex}{文字列の数値拡大率；
    \code{\link{par}("cex")} 倍したものが最終的な文字サイズになる；
    既定の \code{NULL} は \code{1} に等しい．}
  \item{font, vfont, \dots}{フォントに関する追加情報で，
    グラフィックスパラメータ \code{"family"}
    を含むかもしれない：\code{\link{text}} を見よ．}
}
\details{
  文字列の\sQuote{高さ}は
  それが含む改行数 (\code{"\n"}) でだけ決定されることを注意する：
  それは (改行数 - 1) 倍の行間隔に選択されたフォントでの
  \code{"M"} の高さを加えたものである．
  表現式に対してはそれは \link{plotmath} で計算されるバウンディングボックス
  の高さである．
  このようにどちらの場合でもそれは
  タイプセットされたオブジェクトが広がる最終的なベースラインの上に
  どれだけ離れているかを推定する．
  (ベースラインの下にも広がっているかもしれない．)
  行間のスペースは
  \code{cex}, \code{\link{par}("lheight")} そして
  \sQuote{ポイントのサイズ}で制御される
  (しかし実際に使用されるフォントはされない)．

  \code{"user"} 単位(既定)での測定は
  \code{\link{plot.new}} が呼び出された後でのみ利用可能である
  -- さもなければエラーが発生する．
}
\value{
  \code{s} と同じ長さの数値ベクトルで，
  各 \code{s[i]} の幅と高さの推定値を与える．\code{NA} 文字は
  幅と高さがゼロ
  (それらはプロットされないので)である．
}
\seealso{
  \code{\link{text}}, \code{\link{nchar}}
}
\examples{
str.ex <- c("W","w","I",".","WwI.")
op <- par(pty = "s"); plot(1:100, 1:100, type = "n")
sw <- strwidth(str.ex); sw
all.equal(sum(sw[1:4]), sw[5])
#- 最後の文字列は他を含むので

sw.i <- strwidth(str.ex, "inches"); 25.4 * sw.i  # 幅 [mm 単位]
unique(sw / sw.i)
# 定数因子：値一つ
mean(sw.i / strwidth(str.ex, "fig")) / par('fin')[1]  # = 1: 同じ

## 文字がどのようにクラスに入るかを見る
##  -- グラフィックスデバイスとフォントによる!
all.lett <- c(letters, LETTERS)
shL <- strheight(all.lett, units = "inches") * 72  # 'big points'
table(shL)  # 全ては同じ高さを持つ ...
mean(shL)/par("cin")[2] # 約 0.6

(swL <- strwidth(all.lett, units = "inches") * 72)  # 'big points'
split(all.lett, factor(round(swL, 2)))

sumex <- expression(sum(x[i], i=1,n), e^{i * pi} == -1)
strwidth(sumex)
strheight(sumex)

par(op)  #- 以前の設定にリセット
}
\keyword{dplot}
\keyword{character}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/graphics/man/strwidth.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2011 R Core Team
%% Distributed under GPL 2 or later
%
%\name{strwidth}
%\title{Plotting Dimensions of Character Strings and Math Expressions}
%\description{
%  These functions compute the width or height, respectively, of the
%  given strings or mathematical expressions \code{s[i]} on
%  the current plotting device in \emph{user} coordinates, \emph{inches}
%  or as fraction of the figure width \code{par("fin")}.
%}
%\usage{
%strwidth(s, units = "user", cex = NULL, font = NULL, vfont = NULL, ...)
%strheight(s, units = "user", cex = NULL, font = NULL, vfont = NULL, ...)
%}
%\alias{strwidth}
%\alias{strheight}
%\arguments{
%  \item{s}{a character or \link{expression} vector whose dimensions
%    are to be determined.  Other objects are coerced by
%    \code{\link{as.graphicsAnnot}}.}
%  \item{units}{character indicating in which units \code{s} is measured;
%    should be one of \code{"user"}, \code{"inches"}, \code{"figure"};
%    partial matching is performed.}
%  \item{cex}{numeric \bold{c}haracter \bold{ex}pansion factor; multiplied
%    by \code{\link{par}("cex")} yields the final character size; the
%    default \code{NULL} is equivalent to \code{1}.}
%  \item{font, vfont, \dots}{additional information about the font,
%    possibly including the graphics parameter \code{"family"}:
%    see \code{\link{text}}.}
%}
%\details{
%  Note that the \sQuote{height} of a string is determined only by the
%  number of linefeeds (\code{"\n"}) it contains: it is the (number of
%  linefeeds - 1) times the line spacing plus the height of \code{"M"} in
%  the selected font.  For an expression it is the height of the
%  bounding box as computed by \link{plotmath}.  Thus in both cases it is
%  an estimate of how far \bold{above} the final baseline the typeset
%  object extends.  (It may also extend below the baseline.)  The
%  inter-line spacing is controlled by \code{cex},
%  \code{\link{par}("lheight")} and the \sQuote{point size} (but not the
%  actual font in use).
%
%  Measurements in \code{"user"} units (the default) are only available
%  after \code{\link{plot.new}} has been called -- otherwise an error is
%  thrown.
%}
%\value{
%  Numeric vector with the same length as \code{s}, giving the estimate of
%  width or height for each \code{s[i]}.  \code{NA} strings are given
%  width and height 0 (as they are not plotted).
%}
%\seealso{
%  \code{\link{text}}, \code{\link{nchar}}
%}
%\examples{
%str.ex <- c("W","w","I",".","WwI.")
%op <- par(pty = "s"); plot(1:100, 1:100, type = "n")
%sw <- strwidth(str.ex); sw
%all.equal(sum(sw[1:4]), sw[5])
%#- since the last string contains the others
%
%sw.i <- strwidth(str.ex, "inches"); 25.4 * sw.i  # width in [mm]
%unique(sw / sw.i)
%# constant factor: 1 value
%mean(sw.i / strwidth(str.ex, "fig")) / par('fin')[1]  # = 1: are the same
%
%## See how letters fall in classes
%##  -- depending on graphics device and font!
%all.lett <- c(letters, LETTERS)
%shL <- strheight(all.lett, units = "inches") * 72  # 'big points'
%table(shL)  # all have same heights ...
%mean(shL)/par("cin")[2] # around 0.6
%
%(swL <- strwidth(all.lett, units = "inches") * 72)  # 'big points'
%split(all.lett, factor(round(swL, 2)))
%
%sumex <- expression(sum(x[i], i=1,n), e^{i * pi} == -1)
%strwidth(sumex)
%strheight(sumex)
%
%par(op)  #- reset to previous setting
%}
%\keyword{dplot}
%\keyword{character}
%
%\encoding{UTF8}
%