% File src/library/graphics/man/title.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2016 R Core Team
% Distributed under GPL 2 or later

\name{title}
\title{Plot Annotation}
\usage{
title(main = NULL, sub = NULL, xlab = NULL, ylab = NULL,
      line = NA, outer = FALSE, \dots)
}
\alias{title}
\arguments{
  \item{main}{(トップの)主タイトル，
    フォント，サイズ(文字拡大率)そして
    色が\cr
    \code{par(c("font.main", "cex.main", "col.main"))}．}
  \item{sub}{
    フォント，サイズそして色が
    \code{par(c("font.sub", "cex.sub", "col.sub"))}
    の(底部の)副タイトル．}
  \item{xlab}{
    フォント，サイズそして色
    \code{par(c("font.lab", "cex.lab", "col.lab"))}
    を使った X 軸ラベル．}
  \item{ylab}{Y 軸ラベル，\code{xlab} と同じ属性．}
  \item{line}{
    \code{line} に対する値を指定するとラベルの既定位置を上書きし，
    それらをプロットの端からこの回数の行数分外に置く．}
  \item{outer}{論理値．もし \code{TRUE} ならタイトルは
    プロットの外部余白に置かれる．}
  \item{\dots}{
    \code{\link{par}} からの追加のグラフィカルパラメータ．
    単に \code{col} や \code{cex} を使う代わりに
    例えば \code{col.main} や \code{cex.sub} を使おう．
    \code{adj} はタイトルの整列化を制御する．
    \code{xpd} はクリップ領域を設定するのに使える：
    \code{outer = TRUE} で無い限りこれの既定値は図領域になり，
    さもなけれデバイス領域で，増やすことだけが出来る．
    \code{mgp} は軸タイトルの既定の位置を制御する．
  }
}
\description{
  この関数はプロットにラベルを加えるのに使われる．
  その最初の四つの主要な引数はほとんどの高水準プロット関数にも使える．
  それらは文字型か表現式型でなければならない．
  後者の場合
  下付き・上付き添字，ギリシャ文字，分数等の非常に限られた
  数学表現だけが利用できる：
  \link{plotmath} を見よ．
}
\details{
  \code{title} に渡されたラベルは文字列又は
  言語オブジェクト(名前，呼び出し又は表現式)，そしてプロットされる
  文字列を含むリスト，
  オプションの修正用グラフィカルパラメータ \code{cex=}, \code{col=} そして
  \code{font=} が可能である．
  他のオブジェクトは
  \code{\link{as.graphicsAnnot}} で強制変換される．

  \code{main} の位置の既定値は
  (外部)余白 3 中に垂直に中央化され，
  プロット領域(\code{outer = TRUE} に対してはデバイス領域)
  上で \code{par("adj")} に従って水平に揃えられる．

  \code{xlab}, \code{ylab} そして \code{sub} の位置は
  適当な余白の \code{line} 
  (\code{xlab} と \code{ylab} に対する既定値は
  \code{par("mgp")[1]} で \code{sub} に対しては \code{1}
  だけ増やされる)行で(高さは \code{par("mex")})，
  プロット/デバイス領域上テキスト方向に \code{par("adj")} に
  従って揃えられる．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\seealso{
  \code{\link{mtext}}, \code{\link{text}};
  数学的注釈についての詳細は \code{\link{plotmath}}．
}
\examples{
plot(cars, main = "") # 主タイトルをここで直接使うことも出来た
title(main = "Stopping Distance versus Speed")

plot(cars, main = "")
title(main = list("Stopping Distance versus Speed", cex = 1.5,
                  col = "red", font = 3))

## 指定 "..." :
plot(1, col.axis = "sky blue", col.lab = "thistle")
title("Main Title", sub = "sub title",
      cex.main = 2,   font.main= 4, col.main= "blue",
      cex.sub = 0.75, font.sub = 3, col.sub = "red")


x <- seq(-4, 4, len = 101)
y <- cbind(sin(x), cos(x))
matplot(x, y, type = "l", xaxt = "n",
        main = expression(paste(plain(sin) * phi, "  and  ",
                                plain(cos) * phi)),
        ylab = expression("sin" * phi, "cos" * phi), # 最初だけが使われる
        xlab = expression(paste("Phase Angle ", phi)),
        col.main = "blue")
axis(1, at = c(-pi, -pi/2, 0, pi/2, pi),
     labels = expression(-pi, -pi/2, 0, pi/2, pi))
abline(h = 0, v = pi/2 * c(-1,1), lty = 2, lwd = .1, col = "gray70")
}
\keyword{aplot}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/graphics/man/title.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2016 R Core Team
%% Distributed under GPL 2 or later
%
%\name{title}
%\title{Plot Annotation}
%\usage{
%title(main = NULL, sub = NULL, xlab = NULL, ylab = NULL,
%      line = NA, outer = FALSE, \dots)
%}
%\alias{title}
%\arguments{
%  \item{main}{The main title (on top) using font, size (character
%    expansion) and color \code{par(c("font.main", "cex.main", "col.main"))}.}
%  \item{sub}{Sub-title (at bottom) using font, size and color 
%    \code{par(c("font.sub", "cex.sub", "col.sub"))}.}
%  \item{xlab}{X axis label using font, size and color 
%    \code{par(c("font.lab", "cex.lab", "col.lab"))}.}
%  \item{ylab}{Y axis label, same font attributes as \code{xlab}.}
%  \item{line}{specifying a value for \code{line} overrides the
%    default placement of labels, and places them this many lines
%    outwards from the plot edge.}
%  \item{outer}{a logical value.  If \code{TRUE}, the titles are
%    placed in the outer margins of the plot.}
%  \item{\dots}{further \link{graphical parameters} from \code{\link{par}}.  Use
%    e.g., \code{col.main} or \code{cex.sub} instead of just \code{col}
%    or \code{cex}.  \code{adj} controls the justification of the titles.
%    \code{xpd} can be used to set the clipping region:
%    this defaults to the figure region unless \code{outer = TRUE},
%    otherwise the device region and can only be increased.  \code{mgp}
%    controls the default placing of the axis titles.
%  }
%}
%\description{
%  This function can be used to add labels to a plot.  Its first four
%  principal arguments can also be used as arguments in most high-level
%  plotting functions.  They must be of type \code{\link{character}} or
%  \code{\link{expression}}. In the latter case, quite a bit of
%  mathematical notation is available such as sub- and superscripts,
%  greek letters, fractions, etc: see \link{plotmath}
%}
%\details{
%  The labels passed to \code{title} can be character strings or
%  language objects (names, calls or expressions), or a list
%  containing the string to be plotted, and a selection of the optional
%  modifying \link{graphical parameters} \code{cex=}, \code{col=} and
%  \code{font=}.  Other objects will be coerced by
%  \code{\link{as.graphicsAnnot}}.
%
%  The position of \code{main} defaults to being vertically centered in
%  (outer) margin 3 and justified horizontally according to
%  \code{par("adj")} on the plot region (device region for
%  \code{outer = TRUE}).
%
%  The positions of \code{xlab}, \code{ylab} and \code{sub} are
%  \code{line} (default for \code{xlab} and \code{ylab} being
%  \code{par("mgp")[1]} and increased by \code{1} for \code{sub}) lines
%  (of height \code{par("mex")}) into the appropriate margin, justified
%  in the text direction according to \code{par("adj")} on the
%  plot/device region.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{mtext}}, \code{\link{text}};
%  \code{\link{plotmath}} for details on mathematical annotation.
%}
%\examples{
%plot(cars, main = "") # here, could use main directly
%title(main = "Stopping Distance versus Speed")
%
%plot(cars, main = "")
%title(main = list("Stopping Distance versus Speed", cex = 1.5,
%                  col = "red", font = 3))
%
%## Specifying "..." :
%plot(1, col.axis = "sky blue", col.lab = "thistle")
%title("Main Title", sub = "sub title",
%      cex.main = 2,   font.main= 4, col.main= "blue",
%      cex.sub = 0.75, font.sub = 3, col.sub = "red")
%
%
%x <- seq(-4, 4, len = 101)
%y <- cbind(sin(x), cos(x))
%matplot(x, y, type = "l", xaxt = "n",
%        main = expression(paste(plain(sin) * phi, "  and  ",
%                                plain(cos) * phi)),
%        ylab = expression("sin" * phi, "cos" * phi), # only 1st is taken
%        xlab = expression(paste("Phase Angle ", phi)),
%        col.main = "blue")
%axis(1, at = c(-pi, -pi/2, 0, pi/2, pi),
%     labels = expression(-pi, -pi/2, 0, pi/2, pi))
%abline(h = 0, v = pi/2 * c(-1,1), lty = 2, lwd = .1, col = "gray70")
%}
%\keyword{aplot}
%
%\encoding{UTF8}
%